internaldomains

package
v1.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 5, 2026 License: Apache-2.0 Imports: 21 Imported by: 0

README

Go API client for internaldomains

Manage the internal domains in your organization.

Overview

This API client was generated by the OpenAPI Generator project. By using the OpenAPI-spec from a remote server, you can easily generate an API client.

  • API version: 2.0.0
  • Package version: 1.0.0
  • Generator version: 7.21.0-SNAPSHOT
  • Build package: org.openapitools.codegen.languages.GoClientCodegen

Installation

Import the package in a go file in your project and run go mod tidy:

import internaldomains "github.com/CiscoDevNet/go-ciscosecureaccess/internaldomains"

To use a proxy, set the environment variable HTTP_PROXY:

os.Setenv("HTTP_PROXY", "http://proxy_name:proxy_port")

Configuration of Server URL

Default configuration comes with Servers field that contains server objects as defined in the OpenAPI specification.

Select Server Configuration

For using other server than the one defined on index 0 set context value internaldomains.ContextServerIndex of type int.

ctx := context.WithValue(context.Background(), internaldomains.ContextServerIndex, 1)
Templated Server URL

Templated server URL is formatted using default variables from configuration or from context value internaldomains.ContextServerVariables of type map[string]string.

ctx := context.WithValue(context.Background(), internaldomains.ContextServerVariables, map[string]string{
	"basePath": "v2",
})

Note, enum values are always validated and all unused variables are silently ignored.

URLs Configuration per Operation

Each operation can use different server URL defined using OperationServers map in the Configuration. An operation is uniquely identified by "{classname}Service.{nickname}" string. Similar rules for overriding default operation server index and variables applies by using internaldomains.ContextOperationServerIndices and internaldomains.ContextOperationServerVariables context maps.

ctx := context.WithValue(context.Background(), internaldomains.ContextOperationServerIndices, map[string]int{
	"{classname}Service.{nickname}": 2,
})
ctx = context.WithValue(context.Background(), internaldomains.ContextOperationServerVariables, map[string]map[string]string{
	"{classname}Service.{nickname}": {
		"port": "8443",
	},
})

Documentation for API Endpoints

All URIs are relative to https://api.sse.cisco.com/deployments/v2

Class Method HTTP request Description
InternalDomainsAPI CreateInternalDomain Post /internaldomains Create Internal Domain
InternalDomainsAPI DeleteInternalDomain Delete /internaldomains/{internalDomainId} Delete Internal Domain
InternalDomainsAPI GetInternalDomain Get /internaldomains/{internalDomainId} Get Internal Domain
InternalDomainsAPI ListInternalDomains Get /internaldomains List Internal Domains
InternalDomainsAPI UpdateInternalDomain Put /internaldomains/{internalDomainId} Update Internal Domain

Documentation For Models

Documentation For Authorization

Authentication schemes defined for the API:

oauthFlow
  • Type: OAuth
  • Flow: application
  • Authorization URL:
  • Scopes:
  • deployments.internaldomains:write: Write deployments internal domains
  • deployments.internaldomains:read: Read deployments internal domains

Example

auth := context.WithValue(context.Background(), internaldomains.ContextAccessToken, "ACCESSTOKENSTRING")
r, err := client.Service.Operation(auth, args)

Or via OAuth2 module to automatically refresh tokens and perform user authentication.

import "golang.org/x/oauth2"

/* Perform OAuth2 round trip request and obtain a token */

tokenSource := oauth2cfg.TokenSource(createContext(httpClient), &token)
auth := context.WithValue(oauth2.NoContext, internaldomains.ContextOAuth2, tokenSource)
r, err := client.Service.Operation(auth, args)

Documentation for Utility Methods

Due to the fact that model structure members are all pointers, this package contains a number of utility functions to easily obtain pointers to values of basic types. Each of these functions takes a value of the given basic type and returns a pointer to it:

  • PtrBool
  • PtrInt
  • PtrInt32
  • PtrInt64
  • PtrFloat
  • PtrFloat32
  • PtrFloat64
  • PtrString
  • PtrTime

Author

Documentation

Index

Constants

This section is empty.

Variables

var (
	JsonCheck = regexp.MustCompile(`(?i:(?:application|text)/(?:[^;]+\+)?json)`)
	XmlCheck  = regexp.MustCompile(`(?i:(?:application|text)/(?:[^;]+\+)?xml)`)
)
var (
	// ContextOAuth2 takes an oauth2.TokenSource as authentication for the request.
	ContextOAuth2 = contextKey("token")

	// ContextServerIndex uses a server configuration from the index.
	ContextServerIndex = contextKey("serverIndex")

	// ContextOperationServerIndices uses a server configuration from the index mapping.
	ContextOperationServerIndices = contextKey("serverOperationIndices")

	// ContextServerVariables overrides a server configuration variables.
	ContextServerVariables = contextKey("serverVariables")

	// ContextOperationServerVariables overrides a server configuration variables using operation specific values.
	ContextOperationServerVariables = contextKey("serverOperationVariables")
)

Functions

func CacheExpires

func CacheExpires(r *http.Response) time.Time

CacheExpires helper function to determine remaining time before repeating a request.

func IsNil

func IsNil(i interface{}) bool

IsNil checks if an input is nil

func PtrBool

func PtrBool(v bool) *bool

PtrBool is a helper routine that returns a pointer to given boolean value.

func PtrFloat32

func PtrFloat32(v float32) *float32

PtrFloat32 is a helper routine that returns a pointer to given float value.

func PtrFloat64

func PtrFloat64(v float64) *float64

PtrFloat64 is a helper routine that returns a pointer to given float value.

func PtrInt

func PtrInt(v int) *int

PtrInt is a helper routine that returns a pointer to given integer value.

func PtrInt32

func PtrInt32(v int32) *int32

PtrInt32 is a helper routine that returns a pointer to given integer value.

func PtrInt64

func PtrInt64(v int64) *int64

PtrInt64 is a helper routine that returns a pointer to given integer value.

func PtrString

func PtrString(v string) *string

PtrString is a helper routine that returns a pointer to given string value.

func PtrTime

func PtrTime(v time.Time) *time.Time

PtrTime is helper routine that returns a pointer to given Time value.

Types

type APIClient

type APIClient struct {
	InternalDomainsAPI *InternalDomainsAPIService
	// contains filtered or unexported fields
}

APIClient manages communication with the Cisco Secure Access Internal Domains API API v2.0.0 In most cases there should be only one, shared, APIClient.

func NewAPIClient

func NewAPIClient(cfg *Configuration) *APIClient

NewAPIClient creates a new API client. Requires a userAgent string describing your application. optionally a custom http.Client to allow for advanced features such as caching.

func (*APIClient) GetConfig

func (c *APIClient) GetConfig() *Configuration

Allow modification of underlying config for alternate implementations and testing Caution: modifying the configuration while live can cause data races and potentially unwanted behavior

type APIKey

type APIKey struct {
	Key    string
	Prefix string
}

APIKey provides API key based authentication to a request passed via context using ContextAPIKey

type APIResponse

type APIResponse struct {
	*http.Response `json:"-"`
	Message        string `json:"message,omitempty"`
	// Operation is the name of the OpenAPI operation.
	Operation string `json:"operation,omitempty"`
	// RequestURL is the request URL. This value is always available, even if the
	// embedded *http.Response is nil.
	RequestURL string `json:"url,omitempty"`
	// Method is the HTTP method used for the request.  This value is always
	// available, even if the embedded *http.Response is nil.
	Method string `json:"method,omitempty"`
	// Payload holds the contents of the response body (which may be nil or empty).
	// This is provided here as the raw response.Body() reader will have already
	// been drained.
	Payload []byte `json:"-"`
}

APIResponse stores the API response returned by the server.

func NewAPIResponse

func NewAPIResponse(r *http.Response) *APIResponse

NewAPIResponse returns a new APIResponse object.

func NewAPIResponseWithError

func NewAPIResponseWithError(errorMessage string) *APIResponse

NewAPIResponseWithError returns a new APIResponse object with the provided error message.

type ApiCreateInternalDomainRequest

type ApiCreateInternalDomainRequest struct {
	ApiService *InternalDomainsAPIService
	// contains filtered or unexported fields
}

func (ApiCreateInternalDomainRequest) CreateInternalDomainRequest

func (r ApiCreateInternalDomainRequest) CreateInternalDomainRequest(createInternalDomainRequest CreateInternalDomainRequest) ApiCreateInternalDomainRequest

Create the internal domain.

func (ApiCreateInternalDomainRequest) Execute

type ApiDeleteInternalDomainRequest

type ApiDeleteInternalDomainRequest struct {
	ApiService *InternalDomainsAPIService
	// contains filtered or unexported fields
}

func (ApiDeleteInternalDomainRequest) Execute

type ApiGetInternalDomainRequest

type ApiGetInternalDomainRequest struct {
	ApiService *InternalDomainsAPIService
	// contains filtered or unexported fields
}

func (ApiGetInternalDomainRequest) Execute

type ApiListInternalDomainsRequest

type ApiListInternalDomainsRequest struct {
	ApiService *InternalDomainsAPIService
	// contains filtered or unexported fields
}

func (ApiListInternalDomainsRequest) Execute

func (ApiListInternalDomainsRequest) Limit

The number of records in the collection to return on the page.

func (ApiListInternalDomainsRequest) Page

The number of a page in the collection.

type ApiUpdateInternalDomainRequest

type ApiUpdateInternalDomainRequest struct {
	ApiService *InternalDomainsAPIService
	// contains filtered or unexported fields
}

func (ApiUpdateInternalDomainRequest) CreateInternalDomainRequest

func (r ApiUpdateInternalDomainRequest) CreateInternalDomainRequest(createInternalDomainRequest CreateInternalDomainRequest) ApiUpdateInternalDomainRequest

Create the internal domain.

func (ApiUpdateInternalDomainRequest) Execute

type BasicAuth

type BasicAuth struct {
	UserName string `json:"userName,omitempty"`
	Password string `json:"password,omitempty"`
}

BasicAuth provides basic http authentication to a request passed via context using ContextBasicAuth

type Configuration

type Configuration struct {
	Host             string            `json:"host,omitempty"`
	Scheme           string            `json:"scheme,omitempty"`
	DefaultHeader    map[string]string `json:"defaultHeader,omitempty"`
	UserAgent        string            `json:"userAgent,omitempty"`
	Debug            bool              `json:"debug,omitempty"`
	Servers          ServerConfigurations
	OperationServers map[string]ServerConfigurations
	HTTPClient       *http.Client
}

Configuration stores the configuration of the API client

func NewConfiguration

func NewConfiguration() *Configuration

NewConfiguration returns a new Configuration object

func (*Configuration) AddDefaultHeader

func (c *Configuration) AddDefaultHeader(key string, value string)

AddDefaultHeader adds a new HTTP header to the default header in the request

func (*Configuration) ServerURL

func (c *Configuration) ServerURL(index int, variables map[string]string) (string, error)

ServerURL returns URL based on server settings

func (*Configuration) ServerURLWithContext

func (c *Configuration) ServerURLWithContext(ctx context.Context, endpoint string) (string, error)

ServerURLWithContext returns a new server URL given an endpoint

type CreateInternalDomainRequest

type CreateInternalDomainRequest struct {
	// The internal domain.
	Domain string `json:"domain"`
	// The description of the internal domain. The description is a sequence of characters with a length from 1 through 50.
	Description *string `json:"description,omitempty"`
	// Specifies whether to apply the internal domain to all virtual appliances.
	IncludeAllVAs *bool `json:"includeAllVAs,omitempty"`
	// Specifies whether to apply the internal domain to all mobile devices.
	IncludeAllMobileDevices *bool `json:"includeAllMobileDevices,omitempty"`
	// The list of site IDs associated with the domain.
	SiteIds              []int64 `json:"siteIds,omitempty"`
	AdditionalProperties map[string]interface{}
}

CreateInternalDomainRequest struct for CreateInternalDomainRequest

func NewCreateInternalDomainRequest

func NewCreateInternalDomainRequest(domain string) *CreateInternalDomainRequest

NewCreateInternalDomainRequest instantiates a new CreateInternalDomainRequest object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewCreateInternalDomainRequestWithDefaults

func NewCreateInternalDomainRequestWithDefaults() *CreateInternalDomainRequest

NewCreateInternalDomainRequestWithDefaults instantiates a new CreateInternalDomainRequest object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*CreateInternalDomainRequest) GetDescription

func (o *CreateInternalDomainRequest) GetDescription() string

GetDescription returns the Description field value if set, zero value otherwise.

func (*CreateInternalDomainRequest) GetDescriptionOk

func (o *CreateInternalDomainRequest) GetDescriptionOk() (*string, bool)

GetDescriptionOk returns a tuple with the Description field value if set, nil otherwise and a boolean to check if the value has been set.

func (*CreateInternalDomainRequest) GetDomain

func (o *CreateInternalDomainRequest) GetDomain() string

GetDomain returns the Domain field value

func (*CreateInternalDomainRequest) GetDomainOk

func (o *CreateInternalDomainRequest) GetDomainOk() (*string, bool)

GetDomainOk returns a tuple with the Domain field value and a boolean to check if the value has been set.

func (*CreateInternalDomainRequest) GetIncludeAllMobileDevices

func (o *CreateInternalDomainRequest) GetIncludeAllMobileDevices() bool

GetIncludeAllMobileDevices returns the IncludeAllMobileDevices field value if set, zero value otherwise.

func (*CreateInternalDomainRequest) GetIncludeAllMobileDevicesOk

func (o *CreateInternalDomainRequest) GetIncludeAllMobileDevicesOk() (*bool, bool)

GetIncludeAllMobileDevicesOk returns a tuple with the IncludeAllMobileDevices field value if set, nil otherwise and a boolean to check if the value has been set.

func (*CreateInternalDomainRequest) GetIncludeAllVAs

func (o *CreateInternalDomainRequest) GetIncludeAllVAs() bool

GetIncludeAllVAs returns the IncludeAllVAs field value if set, zero value otherwise.

func (*CreateInternalDomainRequest) GetIncludeAllVAsOk

func (o *CreateInternalDomainRequest) GetIncludeAllVAsOk() (*bool, bool)

GetIncludeAllVAsOk returns a tuple with the IncludeAllVAs field value if set, nil otherwise and a boolean to check if the value has been set.

func (*CreateInternalDomainRequest) GetSiteIds

func (o *CreateInternalDomainRequest) GetSiteIds() []int64

GetSiteIds returns the SiteIds field value if set, zero value otherwise.

func (*CreateInternalDomainRequest) GetSiteIdsOk

func (o *CreateInternalDomainRequest) GetSiteIdsOk() ([]int64, bool)

GetSiteIdsOk returns a tuple with the SiteIds field value if set, nil otherwise and a boolean to check if the value has been set.

func (*CreateInternalDomainRequest) HasDescription

func (o *CreateInternalDomainRequest) HasDescription() bool

HasDescription returns a boolean if a field has been set.

func (*CreateInternalDomainRequest) HasIncludeAllMobileDevices

func (o *CreateInternalDomainRequest) HasIncludeAllMobileDevices() bool

HasIncludeAllMobileDevices returns a boolean if a field has been set.

func (*CreateInternalDomainRequest) HasIncludeAllVAs

func (o *CreateInternalDomainRequest) HasIncludeAllVAs() bool

HasIncludeAllVAs returns a boolean if a field has been set.

func (*CreateInternalDomainRequest) HasSiteIds

func (o *CreateInternalDomainRequest) HasSiteIds() bool

HasSiteIds returns a boolean if a field has been set.

func (CreateInternalDomainRequest) MarshalJSON

func (o CreateInternalDomainRequest) MarshalJSON() ([]byte, error)

func (*CreateInternalDomainRequest) SetDescription

func (o *CreateInternalDomainRequest) SetDescription(v string)

SetDescription gets a reference to the given string and assigns it to the Description field.

func (*CreateInternalDomainRequest) SetDomain

func (o *CreateInternalDomainRequest) SetDomain(v string)

SetDomain sets field value

func (*CreateInternalDomainRequest) SetIncludeAllMobileDevices

func (o *CreateInternalDomainRequest) SetIncludeAllMobileDevices(v bool)

SetIncludeAllMobileDevices gets a reference to the given bool and assigns it to the IncludeAllMobileDevices field.

func (*CreateInternalDomainRequest) SetIncludeAllVAs

func (o *CreateInternalDomainRequest) SetIncludeAllVAs(v bool)

SetIncludeAllVAs gets a reference to the given bool and assigns it to the IncludeAllVAs field.

func (*CreateInternalDomainRequest) SetSiteIds

func (o *CreateInternalDomainRequest) SetSiteIds(v []int64)

SetSiteIds gets a reference to the given []int64 and assigns it to the SiteIds field.

func (CreateInternalDomainRequest) ToMap

func (o CreateInternalDomainRequest) ToMap() (map[string]interface{}, error)

func (*CreateInternalDomainRequest) UnmarshalJSON

func (o *CreateInternalDomainRequest) UnmarshalJSON(data []byte) (err error)

type GenericOpenAPIError

type GenericOpenAPIError struct {
	// contains filtered or unexported fields
}

GenericOpenAPIError Provides access to the body, error and model on returned errors.

func (GenericOpenAPIError) Body

func (e GenericOpenAPIError) Body() []byte

Body returns the raw bytes of the response

func (GenericOpenAPIError) Error

func (e GenericOpenAPIError) Error() string

Error returns non-empty string if there was an error.

func (GenericOpenAPIError) Model

func (e GenericOpenAPIError) Model() interface{}

Model returns the unpacked model of the error

type InternalDomainObject

type InternalDomainObject struct {
	// The ID of the internal domain.
	Id int64 `json:"id"`
	// The domain name of the internal domain.
	Domain string `json:"domain"`
	// The description of the internal domain.
	Description string `json:"description"`
	// Specifies whether to apply the internal domain to all virtual appliances.
	IncludeAllVAs bool `json:"includeAllVAs"`
	// Specifies whether to apply the internal domain to all mobile devices.
	IncludeAllMobileDevices bool `json:"includeAllMobileDevices"`
	// The date and time (ISO 8601 timestamp) when the internal domain was created.
	CreatedAt time.Time `json:"createdAt"`
	// The date and time (ISO 8601 timestamp) when the internal domain was modified.
	ModifiedAt time.Time `json:"modifiedAt"`
	// The list of site IDs associated with the domain.
	SiteIds              []int64 `json:"siteIds"`
	AdditionalProperties map[string]interface{}
}

InternalDomainObject struct for InternalDomainObject

func NewInternalDomainObject

func NewInternalDomainObject(id int64, domain string, description string, includeAllVAs bool, includeAllMobileDevices bool, createdAt time.Time, modifiedAt time.Time, siteIds []int64) *InternalDomainObject

NewInternalDomainObject instantiates a new InternalDomainObject object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewInternalDomainObjectWithDefaults

func NewInternalDomainObjectWithDefaults() *InternalDomainObject

NewInternalDomainObjectWithDefaults instantiates a new InternalDomainObject object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*InternalDomainObject) GetCreatedAt

func (o *InternalDomainObject) GetCreatedAt() time.Time

GetCreatedAt returns the CreatedAt field value

func (*InternalDomainObject) GetCreatedAtOk

func (o *InternalDomainObject) GetCreatedAtOk() (*time.Time, bool)

GetCreatedAtOk returns a tuple with the CreatedAt field value and a boolean to check if the value has been set.

func (*InternalDomainObject) GetDescription

func (o *InternalDomainObject) GetDescription() string

GetDescription returns the Description field value

func (*InternalDomainObject) GetDescriptionOk

func (o *InternalDomainObject) GetDescriptionOk() (*string, bool)

GetDescriptionOk returns a tuple with the Description field value and a boolean to check if the value has been set.

func (*InternalDomainObject) GetDomain

func (o *InternalDomainObject) GetDomain() string

GetDomain returns the Domain field value

func (*InternalDomainObject) GetDomainOk

func (o *InternalDomainObject) GetDomainOk() (*string, bool)

GetDomainOk returns a tuple with the Domain field value and a boolean to check if the value has been set.

func (*InternalDomainObject) GetId

func (o *InternalDomainObject) GetId() int64

GetId returns the Id field value

func (*InternalDomainObject) GetIdOk

func (o *InternalDomainObject) GetIdOk() (*int64, bool)

GetIdOk returns a tuple with the Id field value and a boolean to check if the value has been set.

func (*InternalDomainObject) GetIncludeAllMobileDevices

func (o *InternalDomainObject) GetIncludeAllMobileDevices() bool

GetIncludeAllMobileDevices returns the IncludeAllMobileDevices field value

func (*InternalDomainObject) GetIncludeAllMobileDevicesOk

func (o *InternalDomainObject) GetIncludeAllMobileDevicesOk() (*bool, bool)

GetIncludeAllMobileDevicesOk returns a tuple with the IncludeAllMobileDevices field value and a boolean to check if the value has been set.

func (*InternalDomainObject) GetIncludeAllVAs

func (o *InternalDomainObject) GetIncludeAllVAs() bool

GetIncludeAllVAs returns the IncludeAllVAs field value

func (*InternalDomainObject) GetIncludeAllVAsOk

func (o *InternalDomainObject) GetIncludeAllVAsOk() (*bool, bool)

GetIncludeAllVAsOk returns a tuple with the IncludeAllVAs field value and a boolean to check if the value has been set.

func (*InternalDomainObject) GetModifiedAt

func (o *InternalDomainObject) GetModifiedAt() time.Time

GetModifiedAt returns the ModifiedAt field value

func (*InternalDomainObject) GetModifiedAtOk

func (o *InternalDomainObject) GetModifiedAtOk() (*time.Time, bool)

GetModifiedAtOk returns a tuple with the ModifiedAt field value and a boolean to check if the value has been set.

func (*InternalDomainObject) GetSiteIds

func (o *InternalDomainObject) GetSiteIds() []int64

GetSiteIds returns the SiteIds field value

func (*InternalDomainObject) GetSiteIdsOk

func (o *InternalDomainObject) GetSiteIdsOk() ([]int64, bool)

GetSiteIdsOk returns a tuple with the SiteIds field value and a boolean to check if the value has been set.

func (InternalDomainObject) MarshalJSON

func (o InternalDomainObject) MarshalJSON() ([]byte, error)

func (*InternalDomainObject) SetCreatedAt

func (o *InternalDomainObject) SetCreatedAt(v time.Time)

SetCreatedAt sets field value

func (*InternalDomainObject) SetDescription

func (o *InternalDomainObject) SetDescription(v string)

SetDescription sets field value

func (*InternalDomainObject) SetDomain

func (o *InternalDomainObject) SetDomain(v string)

SetDomain sets field value

func (*InternalDomainObject) SetId

func (o *InternalDomainObject) SetId(v int64)

SetId sets field value

func (*InternalDomainObject) SetIncludeAllMobileDevices

func (o *InternalDomainObject) SetIncludeAllMobileDevices(v bool)

SetIncludeAllMobileDevices sets field value

func (*InternalDomainObject) SetIncludeAllVAs

func (o *InternalDomainObject) SetIncludeAllVAs(v bool)

SetIncludeAllVAs sets field value

func (*InternalDomainObject) SetModifiedAt

func (o *InternalDomainObject) SetModifiedAt(v time.Time)

SetModifiedAt sets field value

func (*InternalDomainObject) SetSiteIds

func (o *InternalDomainObject) SetSiteIds(v []int64)

SetSiteIds sets field value

func (InternalDomainObject) ToMap

func (o InternalDomainObject) ToMap() (map[string]interface{}, error)

func (*InternalDomainObject) UnmarshalJSON

func (o *InternalDomainObject) UnmarshalJSON(data []byte) (err error)

type InternalDomainsAPIService

type InternalDomainsAPIService service

InternalDomainsAPIService InternalDomainsAPI service

func (*InternalDomainsAPIService) CreateInternalDomain

CreateInternalDomain Create Internal Domain

Create an internal domain. If you do not assign a list of sites to the internal domain, the internal domain is associated with all sites in the organization.

@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
@return ApiCreateInternalDomainRequest

func (*InternalDomainsAPIService) CreateInternalDomainExecute

Execute executes the request

@return InternalDomainObject

func (*InternalDomainsAPIService) DeleteInternalDomain

func (a *InternalDomainsAPIService) DeleteInternalDomain(ctx context.Context, internalDomainId int64) ApiDeleteInternalDomainRequest

DeleteInternalDomain Delete Internal Domain

Delete an internal domain.

@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
@param internalDomainId The ID of the internal domain.
@return ApiDeleteInternalDomainRequest

func (*InternalDomainsAPIService) DeleteInternalDomainExecute

func (a *InternalDomainsAPIService) DeleteInternalDomainExecute(r ApiDeleteInternalDomainRequest) (string, *http.Response, error)

Execute executes the request

@return string

func (*InternalDomainsAPIService) GetInternalDomain

func (a *InternalDomainsAPIService) GetInternalDomain(ctx context.Context, internalDomainId int64) ApiGetInternalDomainRequest

GetInternalDomain Get Internal Domain

Get an internal domain.

@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
@param internalDomainId The ID of the internal domain.
@return ApiGetInternalDomainRequest

func (*InternalDomainsAPIService) GetInternalDomainExecute

Execute executes the request

@return InternalDomainObject

func (*InternalDomainsAPIService) ListInternalDomains

ListInternalDomains List Internal Domains

List the internal domains.

@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
@return ApiListInternalDomainsRequest

func (*InternalDomainsAPIService) ListInternalDomainsExecute

Execute executes the request

@return []InternalDomainObject

func (*InternalDomainsAPIService) UpdateInternalDomain

func (a *InternalDomainsAPIService) UpdateInternalDomain(ctx context.Context, internalDomainId int64) ApiUpdateInternalDomainRequest

UpdateInternalDomain Update Internal Domain

Update an internal domain.

@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
@param internalDomainId The ID of the internal domain.
@return ApiUpdateInternalDomainRequest

func (*InternalDomainsAPIService) UpdateInternalDomainExecute

Execute executes the request

@return InternalDomainObject

type ListInternalDomains400Response

type ListInternalDomains400Response struct {
	// HTTP status code
	StatusCode *int64 `json:"statusCode,omitempty"`
	// A brief description of the error
	Error *string `json:"error,omitempty"`
	// Detailed error message
	Message              *string `json:"message,omitempty"`
	AdditionalProperties map[string]interface{}
}

ListInternalDomains400Response struct for ListInternalDomains400Response

func NewListInternalDomains400Response

func NewListInternalDomains400Response() *ListInternalDomains400Response

NewListInternalDomains400Response instantiates a new ListInternalDomains400Response object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewListInternalDomains400ResponseWithDefaults

func NewListInternalDomains400ResponseWithDefaults() *ListInternalDomains400Response

NewListInternalDomains400ResponseWithDefaults instantiates a new ListInternalDomains400Response object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*ListInternalDomains400Response) GetError

func (o *ListInternalDomains400Response) GetError() string

GetError returns the Error field value if set, zero value otherwise.

func (*ListInternalDomains400Response) GetErrorOk

func (o *ListInternalDomains400Response) GetErrorOk() (*string, bool)

GetErrorOk returns a tuple with the Error field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ListInternalDomains400Response) GetMessage

func (o *ListInternalDomains400Response) GetMessage() string

GetMessage returns the Message field value if set, zero value otherwise.

func (*ListInternalDomains400Response) GetMessageOk

func (o *ListInternalDomains400Response) GetMessageOk() (*string, bool)

GetMessageOk returns a tuple with the Message field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ListInternalDomains400Response) GetStatusCode

func (o *ListInternalDomains400Response) GetStatusCode() int64

GetStatusCode returns the StatusCode field value if set, zero value otherwise.

func (*ListInternalDomains400Response) GetStatusCodeOk

func (o *ListInternalDomains400Response) GetStatusCodeOk() (*int64, bool)

GetStatusCodeOk returns a tuple with the StatusCode field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ListInternalDomains400Response) HasError

func (o *ListInternalDomains400Response) HasError() bool

HasError returns a boolean if a field has been set.

func (*ListInternalDomains400Response) HasMessage

func (o *ListInternalDomains400Response) HasMessage() bool

HasMessage returns a boolean if a field has been set.

func (*ListInternalDomains400Response) HasStatusCode

func (o *ListInternalDomains400Response) HasStatusCode() bool

HasStatusCode returns a boolean if a field has been set.

func (ListInternalDomains400Response) MarshalJSON

func (o ListInternalDomains400Response) MarshalJSON() ([]byte, error)

func (*ListInternalDomains400Response) SetError

func (o *ListInternalDomains400Response) SetError(v string)

SetError gets a reference to the given string and assigns it to the Error field.

func (*ListInternalDomains400Response) SetMessage

func (o *ListInternalDomains400Response) SetMessage(v string)

SetMessage gets a reference to the given string and assigns it to the Message field.

func (*ListInternalDomains400Response) SetStatusCode

func (o *ListInternalDomains400Response) SetStatusCode(v int64)

SetStatusCode gets a reference to the given int64 and assigns it to the StatusCode field.

func (ListInternalDomains400Response) ToMap

func (o ListInternalDomains400Response) ToMap() (map[string]interface{}, error)

func (*ListInternalDomains400Response) UnmarshalJSON

func (o *ListInternalDomains400Response) UnmarshalJSON(data []byte) (err error)

type ListInternalDomains401Response

type ListInternalDomains401Response struct {
	// HTTP status code
	StatusCode *int64 `json:"statusCode,omitempty"`
	// A brief description of the error
	Error *string `json:"error,omitempty"`
	// Detailed error message
	Message              *string `json:"message,omitempty"`
	AdditionalProperties map[string]interface{}
}

ListInternalDomains401Response struct for ListInternalDomains401Response

func NewListInternalDomains401Response

func NewListInternalDomains401Response() *ListInternalDomains401Response

NewListInternalDomains401Response instantiates a new ListInternalDomains401Response object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewListInternalDomains401ResponseWithDefaults

func NewListInternalDomains401ResponseWithDefaults() *ListInternalDomains401Response

NewListInternalDomains401ResponseWithDefaults instantiates a new ListInternalDomains401Response object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*ListInternalDomains401Response) GetError

func (o *ListInternalDomains401Response) GetError() string

GetError returns the Error field value if set, zero value otherwise.

func (*ListInternalDomains401Response) GetErrorOk

func (o *ListInternalDomains401Response) GetErrorOk() (*string, bool)

GetErrorOk returns a tuple with the Error field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ListInternalDomains401Response) GetMessage

func (o *ListInternalDomains401Response) GetMessage() string

GetMessage returns the Message field value if set, zero value otherwise.

func (*ListInternalDomains401Response) GetMessageOk

func (o *ListInternalDomains401Response) GetMessageOk() (*string, bool)

GetMessageOk returns a tuple with the Message field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ListInternalDomains401Response) GetStatusCode

func (o *ListInternalDomains401Response) GetStatusCode() int64

GetStatusCode returns the StatusCode field value if set, zero value otherwise.

func (*ListInternalDomains401Response) GetStatusCodeOk

func (o *ListInternalDomains401Response) GetStatusCodeOk() (*int64, bool)

GetStatusCodeOk returns a tuple with the StatusCode field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ListInternalDomains401Response) HasError

func (o *ListInternalDomains401Response) HasError() bool

HasError returns a boolean if a field has been set.

func (*ListInternalDomains401Response) HasMessage

func (o *ListInternalDomains401Response) HasMessage() bool

HasMessage returns a boolean if a field has been set.

func (*ListInternalDomains401Response) HasStatusCode

func (o *ListInternalDomains401Response) HasStatusCode() bool

HasStatusCode returns a boolean if a field has been set.

func (ListInternalDomains401Response) MarshalJSON

func (o ListInternalDomains401Response) MarshalJSON() ([]byte, error)

func (*ListInternalDomains401Response) SetError

func (o *ListInternalDomains401Response) SetError(v string)

SetError gets a reference to the given string and assigns it to the Error field.

func (*ListInternalDomains401Response) SetMessage

func (o *ListInternalDomains401Response) SetMessage(v string)

SetMessage gets a reference to the given string and assigns it to the Message field.

func (*ListInternalDomains401Response) SetStatusCode

func (o *ListInternalDomains401Response) SetStatusCode(v int64)

SetStatusCode gets a reference to the given int64 and assigns it to the StatusCode field.

func (ListInternalDomains401Response) ToMap

func (o ListInternalDomains401Response) ToMap() (map[string]interface{}, error)

func (*ListInternalDomains401Response) UnmarshalJSON

func (o *ListInternalDomains401Response) UnmarshalJSON(data []byte) (err error)

type ListInternalDomains403Response

type ListInternalDomains403Response struct {
	// HTTP status code
	StatusCode *int64 `json:"statusCode,omitempty"`
	// A brief description of the error
	Error *string `json:"error,omitempty"`
	// Detailed error message
	Message              *string `json:"message,omitempty"`
	AdditionalProperties map[string]interface{}
}

ListInternalDomains403Response struct for ListInternalDomains403Response

func NewListInternalDomains403Response

func NewListInternalDomains403Response() *ListInternalDomains403Response

NewListInternalDomains403Response instantiates a new ListInternalDomains403Response object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewListInternalDomains403ResponseWithDefaults

func NewListInternalDomains403ResponseWithDefaults() *ListInternalDomains403Response

NewListInternalDomains403ResponseWithDefaults instantiates a new ListInternalDomains403Response object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*ListInternalDomains403Response) GetError

func (o *ListInternalDomains403Response) GetError() string

GetError returns the Error field value if set, zero value otherwise.

func (*ListInternalDomains403Response) GetErrorOk

func (o *ListInternalDomains403Response) GetErrorOk() (*string, bool)

GetErrorOk returns a tuple with the Error field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ListInternalDomains403Response) GetMessage

func (o *ListInternalDomains403Response) GetMessage() string

GetMessage returns the Message field value if set, zero value otherwise.

func (*ListInternalDomains403Response) GetMessageOk

func (o *ListInternalDomains403Response) GetMessageOk() (*string, bool)

GetMessageOk returns a tuple with the Message field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ListInternalDomains403Response) GetStatusCode

func (o *ListInternalDomains403Response) GetStatusCode() int64

GetStatusCode returns the StatusCode field value if set, zero value otherwise.

func (*ListInternalDomains403Response) GetStatusCodeOk

func (o *ListInternalDomains403Response) GetStatusCodeOk() (*int64, bool)

GetStatusCodeOk returns a tuple with the StatusCode field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ListInternalDomains403Response) HasError

func (o *ListInternalDomains403Response) HasError() bool

HasError returns a boolean if a field has been set.

func (*ListInternalDomains403Response) HasMessage

func (o *ListInternalDomains403Response) HasMessage() bool

HasMessage returns a boolean if a field has been set.

func (*ListInternalDomains403Response) HasStatusCode

func (o *ListInternalDomains403Response) HasStatusCode() bool

HasStatusCode returns a boolean if a field has been set.

func (ListInternalDomains403Response) MarshalJSON

func (o ListInternalDomains403Response) MarshalJSON() ([]byte, error)

func (*ListInternalDomains403Response) SetError

func (o *ListInternalDomains403Response) SetError(v string)

SetError gets a reference to the given string and assigns it to the Error field.

func (*ListInternalDomains403Response) SetMessage

func (o *ListInternalDomains403Response) SetMessage(v string)

SetMessage gets a reference to the given string and assigns it to the Message field.

func (*ListInternalDomains403Response) SetStatusCode

func (o *ListInternalDomains403Response) SetStatusCode(v int64)

SetStatusCode gets a reference to the given int64 and assigns it to the StatusCode field.

func (ListInternalDomains403Response) ToMap

func (o ListInternalDomains403Response) ToMap() (map[string]interface{}, error)

func (*ListInternalDomains403Response) UnmarshalJSON

func (o *ListInternalDomains403Response) UnmarshalJSON(data []byte) (err error)

type ListInternalDomains404Response

type ListInternalDomains404Response struct {
	// HTTP status code
	StatusCode *int64 `json:"statusCode,omitempty"`
	// A brief description of the error
	Error *string `json:"error,omitempty"`
	// Detailed error message
	Message              *string `json:"message,omitempty"`
	AdditionalProperties map[string]interface{}
}

ListInternalDomains404Response struct for ListInternalDomains404Response

func NewListInternalDomains404Response

func NewListInternalDomains404Response() *ListInternalDomains404Response

NewListInternalDomains404Response instantiates a new ListInternalDomains404Response object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewListInternalDomains404ResponseWithDefaults

func NewListInternalDomains404ResponseWithDefaults() *ListInternalDomains404Response

NewListInternalDomains404ResponseWithDefaults instantiates a new ListInternalDomains404Response object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*ListInternalDomains404Response) GetError

func (o *ListInternalDomains404Response) GetError() string

GetError returns the Error field value if set, zero value otherwise.

func (*ListInternalDomains404Response) GetErrorOk

func (o *ListInternalDomains404Response) GetErrorOk() (*string, bool)

GetErrorOk returns a tuple with the Error field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ListInternalDomains404Response) GetMessage

func (o *ListInternalDomains404Response) GetMessage() string

GetMessage returns the Message field value if set, zero value otherwise.

func (*ListInternalDomains404Response) GetMessageOk

func (o *ListInternalDomains404Response) GetMessageOk() (*string, bool)

GetMessageOk returns a tuple with the Message field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ListInternalDomains404Response) GetStatusCode

func (o *ListInternalDomains404Response) GetStatusCode() int64

GetStatusCode returns the StatusCode field value if set, zero value otherwise.

func (*ListInternalDomains404Response) GetStatusCodeOk

func (o *ListInternalDomains404Response) GetStatusCodeOk() (*int64, bool)

GetStatusCodeOk returns a tuple with the StatusCode field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ListInternalDomains404Response) HasError

func (o *ListInternalDomains404Response) HasError() bool

HasError returns a boolean if a field has been set.

func (*ListInternalDomains404Response) HasMessage

func (o *ListInternalDomains404Response) HasMessage() bool

HasMessage returns a boolean if a field has been set.

func (*ListInternalDomains404Response) HasStatusCode

func (o *ListInternalDomains404Response) HasStatusCode() bool

HasStatusCode returns a boolean if a field has been set.

func (ListInternalDomains404Response) MarshalJSON

func (o ListInternalDomains404Response) MarshalJSON() ([]byte, error)

func (*ListInternalDomains404Response) SetError

func (o *ListInternalDomains404Response) SetError(v string)

SetError gets a reference to the given string and assigns it to the Error field.

func (*ListInternalDomains404Response) SetMessage

func (o *ListInternalDomains404Response) SetMessage(v string)

SetMessage gets a reference to the given string and assigns it to the Message field.

func (*ListInternalDomains404Response) SetStatusCode

func (o *ListInternalDomains404Response) SetStatusCode(v int64)

SetStatusCode gets a reference to the given int64 and assigns it to the StatusCode field.

func (ListInternalDomains404Response) ToMap

func (o ListInternalDomains404Response) ToMap() (map[string]interface{}, error)

func (*ListInternalDomains404Response) UnmarshalJSON

func (o *ListInternalDomains404Response) UnmarshalJSON(data []byte) (err error)

type ListInternalDomains500Response

type ListInternalDomains500Response struct {
	// HTTP status code
	StatusCode *int64 `json:"statusCode,omitempty"`
	// A brief description of the error
	Error *string `json:"error,omitempty"`
	// Detailed error message
	Message              *string `json:"message,omitempty"`
	AdditionalProperties map[string]interface{}
}

ListInternalDomains500Response struct for ListInternalDomains500Response

func NewListInternalDomains500Response

func NewListInternalDomains500Response() *ListInternalDomains500Response

NewListInternalDomains500Response instantiates a new ListInternalDomains500Response object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewListInternalDomains500ResponseWithDefaults

func NewListInternalDomains500ResponseWithDefaults() *ListInternalDomains500Response

NewListInternalDomains500ResponseWithDefaults instantiates a new ListInternalDomains500Response object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*ListInternalDomains500Response) GetError

func (o *ListInternalDomains500Response) GetError() string

GetError returns the Error field value if set, zero value otherwise.

func (*ListInternalDomains500Response) GetErrorOk

func (o *ListInternalDomains500Response) GetErrorOk() (*string, bool)

GetErrorOk returns a tuple with the Error field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ListInternalDomains500Response) GetMessage

func (o *ListInternalDomains500Response) GetMessage() string

GetMessage returns the Message field value if set, zero value otherwise.

func (*ListInternalDomains500Response) GetMessageOk

func (o *ListInternalDomains500Response) GetMessageOk() (*string, bool)

GetMessageOk returns a tuple with the Message field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ListInternalDomains500Response) GetStatusCode

func (o *ListInternalDomains500Response) GetStatusCode() int64

GetStatusCode returns the StatusCode field value if set, zero value otherwise.

func (*ListInternalDomains500Response) GetStatusCodeOk

func (o *ListInternalDomains500Response) GetStatusCodeOk() (*int64, bool)

GetStatusCodeOk returns a tuple with the StatusCode field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ListInternalDomains500Response) HasError

func (o *ListInternalDomains500Response) HasError() bool

HasError returns a boolean if a field has been set.

func (*ListInternalDomains500Response) HasMessage

func (o *ListInternalDomains500Response) HasMessage() bool

HasMessage returns a boolean if a field has been set.

func (*ListInternalDomains500Response) HasStatusCode

func (o *ListInternalDomains500Response) HasStatusCode() bool

HasStatusCode returns a boolean if a field has been set.

func (ListInternalDomains500Response) MarshalJSON

func (o ListInternalDomains500Response) MarshalJSON() ([]byte, error)

func (*ListInternalDomains500Response) SetError

func (o *ListInternalDomains500Response) SetError(v string)

SetError gets a reference to the given string and assigns it to the Error field.

func (*ListInternalDomains500Response) SetMessage

func (o *ListInternalDomains500Response) SetMessage(v string)

SetMessage gets a reference to the given string and assigns it to the Message field.

func (*ListInternalDomains500Response) SetStatusCode

func (o *ListInternalDomains500Response) SetStatusCode(v int64)

SetStatusCode gets a reference to the given int64 and assigns it to the StatusCode field.

func (ListInternalDomains500Response) ToMap

func (o ListInternalDomains500Response) ToMap() (map[string]interface{}, error)

func (*ListInternalDomains500Response) UnmarshalJSON

func (o *ListInternalDomains500Response) UnmarshalJSON(data []byte) (err error)

type MappedNullable

type MappedNullable interface {
	ToMap() (map[string]interface{}, error)
}

type NullableBool

type NullableBool struct {
	// contains filtered or unexported fields
}

func NewNullableBool

func NewNullableBool(val *bool) *NullableBool

func (NullableBool) Get

func (v NullableBool) Get() *bool

func (NullableBool) IsSet

func (v NullableBool) IsSet() bool

func (NullableBool) MarshalJSON

func (v NullableBool) MarshalJSON() ([]byte, error)

func (*NullableBool) Set

func (v *NullableBool) Set(val *bool)

func (*NullableBool) UnmarshalJSON

func (v *NullableBool) UnmarshalJSON(src []byte) error

func (*NullableBool) Unset

func (v *NullableBool) Unset()

type NullableCreateInternalDomainRequest

type NullableCreateInternalDomainRequest struct {
	// contains filtered or unexported fields
}

func (NullableCreateInternalDomainRequest) Get

func (NullableCreateInternalDomainRequest) IsSet

func (NullableCreateInternalDomainRequest) MarshalJSON

func (v NullableCreateInternalDomainRequest) MarshalJSON() ([]byte, error)

func (*NullableCreateInternalDomainRequest) Set

func (*NullableCreateInternalDomainRequest) UnmarshalJSON

func (v *NullableCreateInternalDomainRequest) UnmarshalJSON(src []byte) error

func (*NullableCreateInternalDomainRequest) Unset

type NullableFloat32

type NullableFloat32 struct {
	// contains filtered or unexported fields
}

func NewNullableFloat32

func NewNullableFloat32(val *float32) *NullableFloat32

func (NullableFloat32) Get

func (v NullableFloat32) Get() *float32

func (NullableFloat32) IsSet

func (v NullableFloat32) IsSet() bool

func (NullableFloat32) MarshalJSON

func (v NullableFloat32) MarshalJSON() ([]byte, error)

func (*NullableFloat32) Set

func (v *NullableFloat32) Set(val *float32)

func (*NullableFloat32) UnmarshalJSON

func (v *NullableFloat32) UnmarshalJSON(src []byte) error

func (*NullableFloat32) Unset

func (v *NullableFloat32) Unset()

type NullableFloat64

type NullableFloat64 struct {
	// contains filtered or unexported fields
}

func NewNullableFloat64

func NewNullableFloat64(val *float64) *NullableFloat64

func (NullableFloat64) Get

func (v NullableFloat64) Get() *float64

func (NullableFloat64) IsSet

func (v NullableFloat64) IsSet() bool

func (NullableFloat64) MarshalJSON

func (v NullableFloat64) MarshalJSON() ([]byte, error)

func (*NullableFloat64) Set

func (v *NullableFloat64) Set(val *float64)

func (*NullableFloat64) UnmarshalJSON

func (v *NullableFloat64) UnmarshalJSON(src []byte) error

func (*NullableFloat64) Unset

func (v *NullableFloat64) Unset()

type NullableInt

type NullableInt struct {
	// contains filtered or unexported fields
}

func NewNullableInt

func NewNullableInt(val *int) *NullableInt

func (NullableInt) Get

func (v NullableInt) Get() *int

func (NullableInt) IsSet

func (v NullableInt) IsSet() bool

func (NullableInt) MarshalJSON

func (v NullableInt) MarshalJSON() ([]byte, error)

func (*NullableInt) Set

func (v *NullableInt) Set(val *int)

func (*NullableInt) UnmarshalJSON

func (v *NullableInt) UnmarshalJSON(src []byte) error

func (*NullableInt) Unset

func (v *NullableInt) Unset()

type NullableInt32

type NullableInt32 struct {
	// contains filtered or unexported fields
}

func NewNullableInt32

func NewNullableInt32(val *int32) *NullableInt32

func (NullableInt32) Get

func (v NullableInt32) Get() *int32

func (NullableInt32) IsSet

func (v NullableInt32) IsSet() bool

func (NullableInt32) MarshalJSON

func (v NullableInt32) MarshalJSON() ([]byte, error)

func (*NullableInt32) Set

func (v *NullableInt32) Set(val *int32)

func (*NullableInt32) UnmarshalJSON

func (v *NullableInt32) UnmarshalJSON(src []byte) error

func (*NullableInt32) Unset

func (v *NullableInt32) Unset()

type NullableInt64

type NullableInt64 struct {
	// contains filtered or unexported fields
}

func NewNullableInt64

func NewNullableInt64(val *int64) *NullableInt64

func (NullableInt64) Get

func (v NullableInt64) Get() *int64

func (NullableInt64) IsSet

func (v NullableInt64) IsSet() bool

func (NullableInt64) MarshalJSON

func (v NullableInt64) MarshalJSON() ([]byte, error)

func (*NullableInt64) Set

func (v *NullableInt64) Set(val *int64)

func (*NullableInt64) UnmarshalJSON

func (v *NullableInt64) UnmarshalJSON(src []byte) error

func (*NullableInt64) Unset

func (v *NullableInt64) Unset()

type NullableInternalDomainObject

type NullableInternalDomainObject struct {
	// contains filtered or unexported fields
}

func NewNullableInternalDomainObject

func NewNullableInternalDomainObject(val *InternalDomainObject) *NullableInternalDomainObject

func (NullableInternalDomainObject) Get

func (NullableInternalDomainObject) IsSet

func (NullableInternalDomainObject) MarshalJSON

func (v NullableInternalDomainObject) MarshalJSON() ([]byte, error)

func (*NullableInternalDomainObject) Set

func (*NullableInternalDomainObject) UnmarshalJSON

func (v *NullableInternalDomainObject) UnmarshalJSON(src []byte) error

func (*NullableInternalDomainObject) Unset

func (v *NullableInternalDomainObject) Unset()

type NullableListInternalDomains400Response

type NullableListInternalDomains400Response struct {
	// contains filtered or unexported fields
}

func (NullableListInternalDomains400Response) Get

func (NullableListInternalDomains400Response) IsSet

func (NullableListInternalDomains400Response) MarshalJSON

func (v NullableListInternalDomains400Response) MarshalJSON() ([]byte, error)

func (*NullableListInternalDomains400Response) Set

func (*NullableListInternalDomains400Response) UnmarshalJSON

func (v *NullableListInternalDomains400Response) UnmarshalJSON(src []byte) error

func (*NullableListInternalDomains400Response) Unset

type NullableListInternalDomains401Response

type NullableListInternalDomains401Response struct {
	// contains filtered or unexported fields
}

func (NullableListInternalDomains401Response) Get

func (NullableListInternalDomains401Response) IsSet

func (NullableListInternalDomains401Response) MarshalJSON

func (v NullableListInternalDomains401Response) MarshalJSON() ([]byte, error)

func (*NullableListInternalDomains401Response) Set

func (*NullableListInternalDomains401Response) UnmarshalJSON

func (v *NullableListInternalDomains401Response) UnmarshalJSON(src []byte) error

func (*NullableListInternalDomains401Response) Unset

type NullableListInternalDomains403Response

type NullableListInternalDomains403Response struct {
	// contains filtered or unexported fields
}

func (NullableListInternalDomains403Response) Get

func (NullableListInternalDomains403Response) IsSet

func (NullableListInternalDomains403Response) MarshalJSON

func (v NullableListInternalDomains403Response) MarshalJSON() ([]byte, error)

func (*NullableListInternalDomains403Response) Set

func (*NullableListInternalDomains403Response) UnmarshalJSON

func (v *NullableListInternalDomains403Response) UnmarshalJSON(src []byte) error

func (*NullableListInternalDomains403Response) Unset

type NullableListInternalDomains404Response

type NullableListInternalDomains404Response struct {
	// contains filtered or unexported fields
}

func (NullableListInternalDomains404Response) Get

func (NullableListInternalDomains404Response) IsSet

func (NullableListInternalDomains404Response) MarshalJSON

func (v NullableListInternalDomains404Response) MarshalJSON() ([]byte, error)

func (*NullableListInternalDomains404Response) Set

func (*NullableListInternalDomains404Response) UnmarshalJSON

func (v *NullableListInternalDomains404Response) UnmarshalJSON(src []byte) error

func (*NullableListInternalDomains404Response) Unset

type NullableListInternalDomains500Response

type NullableListInternalDomains500Response struct {
	// contains filtered or unexported fields
}

func (NullableListInternalDomains500Response) Get

func (NullableListInternalDomains500Response) IsSet

func (NullableListInternalDomains500Response) MarshalJSON

func (v NullableListInternalDomains500Response) MarshalJSON() ([]byte, error)

func (*NullableListInternalDomains500Response) Set

func (*NullableListInternalDomains500Response) UnmarshalJSON

func (v *NullableListInternalDomains500Response) UnmarshalJSON(src []byte) error

func (*NullableListInternalDomains500Response) Unset

type NullableString

type NullableString struct {
	// contains filtered or unexported fields
}

func NewNullableString

func NewNullableString(val *string) *NullableString

func (NullableString) Get

func (v NullableString) Get() *string

func (NullableString) IsSet

func (v NullableString) IsSet() bool

func (NullableString) MarshalJSON

func (v NullableString) MarshalJSON() ([]byte, error)

func (*NullableString) Set

func (v *NullableString) Set(val *string)

func (*NullableString) UnmarshalJSON

func (v *NullableString) UnmarshalJSON(src []byte) error

func (*NullableString) Unset

func (v *NullableString) Unset()

type NullableTime

type NullableTime struct {
	// contains filtered or unexported fields
}

func NewNullableTime

func NewNullableTime(val *time.Time) *NullableTime

func (NullableTime) Get

func (v NullableTime) Get() *time.Time

func (NullableTime) IsSet

func (v NullableTime) IsSet() bool

func (NullableTime) MarshalJSON

func (v NullableTime) MarshalJSON() ([]byte, error)

func (*NullableTime) Set

func (v *NullableTime) Set(val *time.Time)

func (*NullableTime) UnmarshalJSON

func (v *NullableTime) UnmarshalJSON(src []byte) error

func (*NullableTime) Unset

func (v *NullableTime) Unset()

type ServerConfiguration

type ServerConfiguration struct {
	URL         string
	Description string
	Variables   map[string]ServerVariable
}

ServerConfiguration stores the information about a server

type ServerConfigurations

type ServerConfigurations []ServerConfiguration

ServerConfigurations stores multiple ServerConfiguration items

func (ServerConfigurations) URL

func (sc ServerConfigurations) URL(index int, variables map[string]string) (string, error)

URL formats template on a index using given variables

type ServerVariable

type ServerVariable struct {
	Description  string
	DefaultValue string
	EnumValues   []string
}

ServerVariable stores the information about a server variable

Jump to