sites

package
v1.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 5, 2026 License: Apache-2.0 Imports: 21 Imported by: 0

README

Go API client for sites

Create and manage Sites in the organization.

Overview

This API client was generated by the OpenAPI Generator project. By using the OpenAPI-spec from a remote server, you can easily generate an API client.

  • API version: 2.0.0
  • Package version: 1.0.0
  • Generator version: 7.21.0
  • Build package: org.openapitools.codegen.languages.GoClientCodegen

Installation

Import the package in a go file in your project and run go mod tidy:

import sites "github.com/CiscoDevNet/go-ciscosecureaccess/sites"

To use a proxy, set the environment variable HTTP_PROXY:

os.Setenv("HTTP_PROXY", "http://proxy_name:proxy_port")

Configuration of Server URL

Default configuration comes with Servers field that contains server objects as defined in the OpenAPI specification.

Select Server Configuration

For using other server than the one defined on index 0 set context value sites.ContextServerIndex of type int.

ctx := context.WithValue(context.Background(), sites.ContextServerIndex, 1)
Templated Server URL

Templated server URL is formatted using default variables from configuration or from context value sites.ContextServerVariables of type map[string]string.

ctx := context.WithValue(context.Background(), sites.ContextServerVariables, map[string]string{
	"basePath": "v2",
})

Note, enum values are always validated and all unused variables are silently ignored.

URLs Configuration per Operation

Each operation can use different server URL defined using OperationServers map in the Configuration. An operation is uniquely identified by "{classname}Service.{nickname}" string. Similar rules for overriding default operation server index and variables applies by using sites.ContextOperationServerIndices and sites.ContextOperationServerVariables context maps.

ctx := context.WithValue(context.Background(), sites.ContextOperationServerIndices, map[string]int{
	"{classname}Service.{nickname}": 2,
})
ctx = context.WithValue(context.Background(), sites.ContextOperationServerVariables, map[string]map[string]string{
	"{classname}Service.{nickname}": {
		"port": "8443",
	},
})

Documentation for API Endpoints

All URIs are relative to https://api.sse.cisco.com/deployments/v2

Class Method HTTP request Description
SitesAPI CreateSite Post /sites Create Site
SitesAPI DeleteSite Delete /sites/{siteId} Delete Site
SitesAPI GetSite Get /sites/{siteId} Get Site
SitesAPI ListSites Get /sites List Sites
SitesAPI UpdateSite Put /sites/{siteId} Update Site

Documentation For Models

Documentation For Authorization

Authentication schemes defined for the API:

oauthFlow
  • Type: OAuth
  • Flow: application
  • Authorization URL:
  • Scopes:
  • deployments.sites:write: Write deployments Sites
  • deployments.sites:read: Read deployments Sites

Example

auth := context.WithValue(context.Background(), sites.ContextAccessToken, "ACCESSTOKENSTRING")
r, err := client.Service.Operation(auth, args)

Or via OAuth2 module to automatically refresh tokens and perform user authentication.

import "golang.org/x/oauth2"

/* Perform OAuth2 round trip request and obtain a token */

tokenSource := oauth2cfg.TokenSource(createContext(httpClient), &token)
auth := context.WithValue(oauth2.NoContext, sites.ContextOAuth2, tokenSource)
r, err := client.Service.Operation(auth, args)

Documentation for Utility Methods

Due to the fact that model structure members are all pointers, this package contains a number of utility functions to easily obtain pointers to values of basic types. Each of these functions takes a value of the given basic type and returns a pointer to it:

  • PtrBool
  • PtrInt
  • PtrInt32
  • PtrInt64
  • PtrFloat
  • PtrFloat32
  • PtrFloat64
  • PtrString
  • PtrTime

Author

Documentation

Index

Constants

This section is empty.

Variables

var (
	JsonCheck = regexp.MustCompile(`(?i:(?:application|text)/(?:[^;]+\+)?json)`)
	XmlCheck  = regexp.MustCompile(`(?i:(?:application|text)/(?:[^;]+\+)?xml)`)
)
var (
	// ContextOAuth2 takes an oauth2.TokenSource as authentication for the request.
	ContextOAuth2 = contextKey("token")

	// ContextServerIndex uses a server configuration from the index.
	ContextServerIndex = contextKey("serverIndex")

	// ContextOperationServerIndices uses a server configuration from the index mapping.
	ContextOperationServerIndices = contextKey("serverOperationIndices")

	// ContextServerVariables overrides a server configuration variables.
	ContextServerVariables = contextKey("serverVariables")

	// ContextOperationServerVariables overrides a server configuration variables using operation specific values.
	ContextOperationServerVariables = contextKey("serverOperationVariables")
)

Functions

func CacheExpires

func CacheExpires(r *http.Response) time.Time

CacheExpires helper function to determine remaining time before repeating a request.

func IsNil

func IsNil(i interface{}) bool

IsNil checks if an input is nil

func PtrBool

func PtrBool(v bool) *bool

PtrBool is a helper routine that returns a pointer to given boolean value.

func PtrFloat32

func PtrFloat32(v float32) *float32

PtrFloat32 is a helper routine that returns a pointer to given float value.

func PtrFloat64

func PtrFloat64(v float64) *float64

PtrFloat64 is a helper routine that returns a pointer to given float value.

func PtrInt

func PtrInt(v int) *int

PtrInt is a helper routine that returns a pointer to given integer value.

func PtrInt32

func PtrInt32(v int32) *int32

PtrInt32 is a helper routine that returns a pointer to given integer value.

func PtrInt64

func PtrInt64(v int64) *int64

PtrInt64 is a helper routine that returns a pointer to given integer value.

func PtrString

func PtrString(v string) *string

PtrString is a helper routine that returns a pointer to given string value.

func PtrTime

func PtrTime(v time.Time) *time.Time

PtrTime is helper routine that returns a pointer to given Time value.

Types

type APIClient

type APIClient struct {
	SitesAPI *SitesAPIService
	// contains filtered or unexported fields
}

APIClient manages communication with the Cisco Secure Access Sites API API v2.0.0 In most cases there should be only one, shared, APIClient.

func NewAPIClient

func NewAPIClient(cfg *Configuration) *APIClient

NewAPIClient creates a new API client. Requires a userAgent string describing your application. optionally a custom http.Client to allow for advanced features such as caching.

func (*APIClient) GetConfig

func (c *APIClient) GetConfig() *Configuration

Allow modification of underlying config for alternate implementations and testing Caution: modifying the configuration while live can cause data races and potentially unwanted behavior

type APIKey

type APIKey struct {
	Key    string
	Prefix string
}

APIKey provides API key based authentication to a request passed via context using ContextAPIKey

type APIResponse

type APIResponse struct {
	*http.Response `json:"-"`
	Message        string `json:"message,omitempty"`
	// Operation is the name of the OpenAPI operation.
	Operation string `json:"operation,omitempty"`
	// RequestURL is the request URL. This value is always available, even if the
	// embedded *http.Response is nil.
	RequestURL string `json:"url,omitempty"`
	// Method is the HTTP method used for the request.  This value is always
	// available, even if the embedded *http.Response is nil.
	Method string `json:"method,omitempty"`
	// Payload holds the contents of the response body (which may be nil or empty).
	// This is provided here as the raw response.Body() reader will have already
	// been drained.
	Payload []byte `json:"-"`
}

APIResponse stores the API response returned by the server.

func NewAPIResponse

func NewAPIResponse(r *http.Response) *APIResponse

NewAPIResponse returns a new APIResponse object.

func NewAPIResponseWithError

func NewAPIResponseWithError(errorMessage string) *APIResponse

NewAPIResponseWithError returns a new APIResponse object with the provided error message.

type ApiCreateSiteRequest

type ApiCreateSiteRequest struct {
	ApiService *SitesAPIService
	// contains filtered or unexported fields
}

func (ApiCreateSiteRequest) CreateSiteRequest

func (r ApiCreateSiteRequest) CreateSiteRequest(createSiteRequest CreateSiteRequest) ApiCreateSiteRequest

Register a Site.

func (ApiCreateSiteRequest) Execute

type ApiDeleteSiteRequest

type ApiDeleteSiteRequest struct {
	ApiService *SitesAPIService
	// contains filtered or unexported fields
}

func (ApiDeleteSiteRequest) Execute

func (r ApiDeleteSiteRequest) Execute() (*http.Response, error)

type ApiGetSiteRequest

type ApiGetSiteRequest struct {
	ApiService *SitesAPIService
	// contains filtered or unexported fields
}

func (ApiGetSiteRequest) Execute

func (r ApiGetSiteRequest) Execute() (*SiteObject, *http.Response, error)

type ApiListSitesRequest

type ApiListSitesRequest struct {
	ApiService *SitesAPIService
	// contains filtered or unexported fields
}

func (ApiListSitesRequest) Execute

func (r ApiListSitesRequest) Execute() ([]SiteObject, *http.Response, error)

func (ApiListSitesRequest) Limit

The number of items in the collection to return on the page.

func (ApiListSitesRequest) Page

The number of a page in the collection.

type ApiUpdateSiteRequest

type ApiUpdateSiteRequest struct {
	ApiService *SitesAPIService
	// contains filtered or unexported fields
}

func (ApiUpdateSiteRequest) CreateSiteRequest

func (r ApiUpdateSiteRequest) CreateSiteRequest(createSiteRequest CreateSiteRequest) ApiUpdateSiteRequest

Update the properties of the Site.

func (ApiUpdateSiteRequest) Execute

type BasicAuth

type BasicAuth struct {
	UserName string `json:"userName,omitempty"`
	Password string `json:"password,omitempty"`
}

BasicAuth provides basic http authentication to a request passed via context using ContextBasicAuth

type Configuration

type Configuration struct {
	Host             string            `json:"host,omitempty"`
	Scheme           string            `json:"scheme,omitempty"`
	DefaultHeader    map[string]string `json:"defaultHeader,omitempty"`
	UserAgent        string            `json:"userAgent,omitempty"`
	Debug            bool              `json:"debug,omitempty"`
	Servers          ServerConfigurations
	OperationServers map[string]ServerConfigurations
	HTTPClient       *http.Client
}

Configuration stores the configuration of the API client

func NewConfiguration

func NewConfiguration() *Configuration

NewConfiguration returns a new Configuration object

func (*Configuration) AddDefaultHeader

func (c *Configuration) AddDefaultHeader(key string, value string)

AddDefaultHeader adds a new HTTP header to the default header in the request

func (*Configuration) ServerURL

func (c *Configuration) ServerURL(index int, variables map[string]string) (string, error)

ServerURL returns URL based on server settings

func (*Configuration) ServerURLWithContext

func (c *Configuration) ServerURLWithContext(ctx context.Context, endpoint string) (string, error)

ServerURLWithContext returns a new server URL given an endpoint

type CreateSiteRequest

type CreateSiteRequest struct {
	// The name of the Site. The name is a sequence of 1–255 characters.
	Name                 string `json:"name"`
	AdditionalProperties map[string]interface{}
}

CreateSiteRequest struct for CreateSiteRequest

func NewCreateSiteRequest

func NewCreateSiteRequest(name string) *CreateSiteRequest

NewCreateSiteRequest instantiates a new CreateSiteRequest object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewCreateSiteRequestWithDefaults

func NewCreateSiteRequestWithDefaults() *CreateSiteRequest

NewCreateSiteRequestWithDefaults instantiates a new CreateSiteRequest object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*CreateSiteRequest) GetName

func (o *CreateSiteRequest) GetName() string

GetName returns the Name field value

func (*CreateSiteRequest) GetNameOk

func (o *CreateSiteRequest) GetNameOk() (*string, bool)

GetNameOk returns a tuple with the Name field value and a boolean to check if the value has been set.

func (CreateSiteRequest) MarshalJSON

func (o CreateSiteRequest) MarshalJSON() ([]byte, error)

func (*CreateSiteRequest) SetName

func (o *CreateSiteRequest) SetName(v string)

SetName sets field value

func (CreateSiteRequest) ToMap

func (o CreateSiteRequest) ToMap() (map[string]interface{}, error)

func (*CreateSiteRequest) UnmarshalJSON

func (o *CreateSiteRequest) UnmarshalJSON(data []byte) (err error)

type GenericOpenAPIError

type GenericOpenAPIError struct {
	// contains filtered or unexported fields
}

GenericOpenAPIError Provides access to the body, error and model on returned errors.

func (GenericOpenAPIError) Body

func (e GenericOpenAPIError) Body() []byte

Body returns the raw bytes of the response

func (GenericOpenAPIError) Error

func (e GenericOpenAPIError) Error() string

Error returns non-empty string if there was an error.

func (GenericOpenAPIError) Model

func (e GenericOpenAPIError) Model() interface{}

Model returns the unpacked model of the error

type ListSites400Response

type ListSites400Response struct {
	// HTTP status code
	StatusCode *int64 `json:"statusCode,omitempty"`
	// A brief description of the error
	Error *string `json:"error,omitempty"`
	// Detailed error message
	Message              *string `json:"message,omitempty"`
	AdditionalProperties map[string]interface{}
}

ListSites400Response struct for ListSites400Response

func NewListSites400Response

func NewListSites400Response() *ListSites400Response

NewListSites400Response instantiates a new ListSites400Response object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewListSites400ResponseWithDefaults

func NewListSites400ResponseWithDefaults() *ListSites400Response

NewListSites400ResponseWithDefaults instantiates a new ListSites400Response object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*ListSites400Response) GetError

func (o *ListSites400Response) GetError() string

GetError returns the Error field value if set, zero value otherwise.

func (*ListSites400Response) GetErrorOk

func (o *ListSites400Response) GetErrorOk() (*string, bool)

GetErrorOk returns a tuple with the Error field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ListSites400Response) GetMessage

func (o *ListSites400Response) GetMessage() string

GetMessage returns the Message field value if set, zero value otherwise.

func (*ListSites400Response) GetMessageOk

func (o *ListSites400Response) GetMessageOk() (*string, bool)

GetMessageOk returns a tuple with the Message field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ListSites400Response) GetStatusCode

func (o *ListSites400Response) GetStatusCode() int64

GetStatusCode returns the StatusCode field value if set, zero value otherwise.

func (*ListSites400Response) GetStatusCodeOk

func (o *ListSites400Response) GetStatusCodeOk() (*int64, bool)

GetStatusCodeOk returns a tuple with the StatusCode field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ListSites400Response) HasError

func (o *ListSites400Response) HasError() bool

HasError returns a boolean if a field has been set.

func (*ListSites400Response) HasMessage

func (o *ListSites400Response) HasMessage() bool

HasMessage returns a boolean if a field has been set.

func (*ListSites400Response) HasStatusCode

func (o *ListSites400Response) HasStatusCode() bool

HasStatusCode returns a boolean if a field has been set.

func (ListSites400Response) MarshalJSON

func (o ListSites400Response) MarshalJSON() ([]byte, error)

func (*ListSites400Response) SetError

func (o *ListSites400Response) SetError(v string)

SetError gets a reference to the given string and assigns it to the Error field.

func (*ListSites400Response) SetMessage

func (o *ListSites400Response) SetMessage(v string)

SetMessage gets a reference to the given string and assigns it to the Message field.

func (*ListSites400Response) SetStatusCode

func (o *ListSites400Response) SetStatusCode(v int64)

SetStatusCode gets a reference to the given int64 and assigns it to the StatusCode field.

func (ListSites400Response) ToMap

func (o ListSites400Response) ToMap() (map[string]interface{}, error)

func (*ListSites400Response) UnmarshalJSON

func (o *ListSites400Response) UnmarshalJSON(data []byte) (err error)

type ListSites401Response

type ListSites401Response struct {
	// HTTP status code
	StatusCode *int64 `json:"statusCode,omitempty"`
	// A brief description of the error
	Error *string `json:"error,omitempty"`
	// Detailed error message
	Message              *string `json:"message,omitempty"`
	AdditionalProperties map[string]interface{}
}

ListSites401Response struct for ListSites401Response

func NewListSites401Response

func NewListSites401Response() *ListSites401Response

NewListSites401Response instantiates a new ListSites401Response object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewListSites401ResponseWithDefaults

func NewListSites401ResponseWithDefaults() *ListSites401Response

NewListSites401ResponseWithDefaults instantiates a new ListSites401Response object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*ListSites401Response) GetError

func (o *ListSites401Response) GetError() string

GetError returns the Error field value if set, zero value otherwise.

func (*ListSites401Response) GetErrorOk

func (o *ListSites401Response) GetErrorOk() (*string, bool)

GetErrorOk returns a tuple with the Error field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ListSites401Response) GetMessage

func (o *ListSites401Response) GetMessage() string

GetMessage returns the Message field value if set, zero value otherwise.

func (*ListSites401Response) GetMessageOk

func (o *ListSites401Response) GetMessageOk() (*string, bool)

GetMessageOk returns a tuple with the Message field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ListSites401Response) GetStatusCode

func (o *ListSites401Response) GetStatusCode() int64

GetStatusCode returns the StatusCode field value if set, zero value otherwise.

func (*ListSites401Response) GetStatusCodeOk

func (o *ListSites401Response) GetStatusCodeOk() (*int64, bool)

GetStatusCodeOk returns a tuple with the StatusCode field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ListSites401Response) HasError

func (o *ListSites401Response) HasError() bool

HasError returns a boolean if a field has been set.

func (*ListSites401Response) HasMessage

func (o *ListSites401Response) HasMessage() bool

HasMessage returns a boolean if a field has been set.

func (*ListSites401Response) HasStatusCode

func (o *ListSites401Response) HasStatusCode() bool

HasStatusCode returns a boolean if a field has been set.

func (ListSites401Response) MarshalJSON

func (o ListSites401Response) MarshalJSON() ([]byte, error)

func (*ListSites401Response) SetError

func (o *ListSites401Response) SetError(v string)

SetError gets a reference to the given string and assigns it to the Error field.

func (*ListSites401Response) SetMessage

func (o *ListSites401Response) SetMessage(v string)

SetMessage gets a reference to the given string and assigns it to the Message field.

func (*ListSites401Response) SetStatusCode

func (o *ListSites401Response) SetStatusCode(v int64)

SetStatusCode gets a reference to the given int64 and assigns it to the StatusCode field.

func (ListSites401Response) ToMap

func (o ListSites401Response) ToMap() (map[string]interface{}, error)

func (*ListSites401Response) UnmarshalJSON

func (o *ListSites401Response) UnmarshalJSON(data []byte) (err error)

type ListSites403Response

type ListSites403Response struct {
	// HTTP status code
	StatusCode *int64 `json:"statusCode,omitempty"`
	// A brief description of the error
	Error *string `json:"error,omitempty"`
	// Detailed error message
	Message              *string `json:"message,omitempty"`
	AdditionalProperties map[string]interface{}
}

ListSites403Response struct for ListSites403Response

func NewListSites403Response

func NewListSites403Response() *ListSites403Response

NewListSites403Response instantiates a new ListSites403Response object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewListSites403ResponseWithDefaults

func NewListSites403ResponseWithDefaults() *ListSites403Response

NewListSites403ResponseWithDefaults instantiates a new ListSites403Response object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*ListSites403Response) GetError

func (o *ListSites403Response) GetError() string

GetError returns the Error field value if set, zero value otherwise.

func (*ListSites403Response) GetErrorOk

func (o *ListSites403Response) GetErrorOk() (*string, bool)

GetErrorOk returns a tuple with the Error field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ListSites403Response) GetMessage

func (o *ListSites403Response) GetMessage() string

GetMessage returns the Message field value if set, zero value otherwise.

func (*ListSites403Response) GetMessageOk

func (o *ListSites403Response) GetMessageOk() (*string, bool)

GetMessageOk returns a tuple with the Message field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ListSites403Response) GetStatusCode

func (o *ListSites403Response) GetStatusCode() int64

GetStatusCode returns the StatusCode field value if set, zero value otherwise.

func (*ListSites403Response) GetStatusCodeOk

func (o *ListSites403Response) GetStatusCodeOk() (*int64, bool)

GetStatusCodeOk returns a tuple with the StatusCode field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ListSites403Response) HasError

func (o *ListSites403Response) HasError() bool

HasError returns a boolean if a field has been set.

func (*ListSites403Response) HasMessage

func (o *ListSites403Response) HasMessage() bool

HasMessage returns a boolean if a field has been set.

func (*ListSites403Response) HasStatusCode

func (o *ListSites403Response) HasStatusCode() bool

HasStatusCode returns a boolean if a field has been set.

func (ListSites403Response) MarshalJSON

func (o ListSites403Response) MarshalJSON() ([]byte, error)

func (*ListSites403Response) SetError

func (o *ListSites403Response) SetError(v string)

SetError gets a reference to the given string and assigns it to the Error field.

func (*ListSites403Response) SetMessage

func (o *ListSites403Response) SetMessage(v string)

SetMessage gets a reference to the given string and assigns it to the Message field.

func (*ListSites403Response) SetStatusCode

func (o *ListSites403Response) SetStatusCode(v int64)

SetStatusCode gets a reference to the given int64 and assigns it to the StatusCode field.

func (ListSites403Response) ToMap

func (o ListSites403Response) ToMap() (map[string]interface{}, error)

func (*ListSites403Response) UnmarshalJSON

func (o *ListSites403Response) UnmarshalJSON(data []byte) (err error)

type ListSites404Response

type ListSites404Response struct {
	// HTTP status code
	StatusCode *int64 `json:"statusCode,omitempty"`
	// A brief description of the error
	Error *string `json:"error,omitempty"`
	// Detailed error message
	Message              *string `json:"message,omitempty"`
	AdditionalProperties map[string]interface{}
}

ListSites404Response struct for ListSites404Response

func NewListSites404Response

func NewListSites404Response() *ListSites404Response

NewListSites404Response instantiates a new ListSites404Response object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewListSites404ResponseWithDefaults

func NewListSites404ResponseWithDefaults() *ListSites404Response

NewListSites404ResponseWithDefaults instantiates a new ListSites404Response object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*ListSites404Response) GetError

func (o *ListSites404Response) GetError() string

GetError returns the Error field value if set, zero value otherwise.

func (*ListSites404Response) GetErrorOk

func (o *ListSites404Response) GetErrorOk() (*string, bool)

GetErrorOk returns a tuple with the Error field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ListSites404Response) GetMessage

func (o *ListSites404Response) GetMessage() string

GetMessage returns the Message field value if set, zero value otherwise.

func (*ListSites404Response) GetMessageOk

func (o *ListSites404Response) GetMessageOk() (*string, bool)

GetMessageOk returns a tuple with the Message field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ListSites404Response) GetStatusCode

func (o *ListSites404Response) GetStatusCode() int64

GetStatusCode returns the StatusCode field value if set, zero value otherwise.

func (*ListSites404Response) GetStatusCodeOk

func (o *ListSites404Response) GetStatusCodeOk() (*int64, bool)

GetStatusCodeOk returns a tuple with the StatusCode field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ListSites404Response) HasError

func (o *ListSites404Response) HasError() bool

HasError returns a boolean if a field has been set.

func (*ListSites404Response) HasMessage

func (o *ListSites404Response) HasMessage() bool

HasMessage returns a boolean if a field has been set.

func (*ListSites404Response) HasStatusCode

func (o *ListSites404Response) HasStatusCode() bool

HasStatusCode returns a boolean if a field has been set.

func (ListSites404Response) MarshalJSON

func (o ListSites404Response) MarshalJSON() ([]byte, error)

func (*ListSites404Response) SetError

func (o *ListSites404Response) SetError(v string)

SetError gets a reference to the given string and assigns it to the Error field.

func (*ListSites404Response) SetMessage

func (o *ListSites404Response) SetMessage(v string)

SetMessage gets a reference to the given string and assigns it to the Message field.

func (*ListSites404Response) SetStatusCode

func (o *ListSites404Response) SetStatusCode(v int64)

SetStatusCode gets a reference to the given int64 and assigns it to the StatusCode field.

func (ListSites404Response) ToMap

func (o ListSites404Response) ToMap() (map[string]interface{}, error)

func (*ListSites404Response) UnmarshalJSON

func (o *ListSites404Response) UnmarshalJSON(data []byte) (err error)

type ListSites500Response

type ListSites500Response struct {
	// HTTP status code
	StatusCode *int64 `json:"statusCode,omitempty"`
	// A brief description of the error
	Error *string `json:"error,omitempty"`
	// Detailed error message
	Message              *string `json:"message,omitempty"`
	AdditionalProperties map[string]interface{}
}

ListSites500Response struct for ListSites500Response

func NewListSites500Response

func NewListSites500Response() *ListSites500Response

NewListSites500Response instantiates a new ListSites500Response object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewListSites500ResponseWithDefaults

func NewListSites500ResponseWithDefaults() *ListSites500Response

NewListSites500ResponseWithDefaults instantiates a new ListSites500Response object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*ListSites500Response) GetError

func (o *ListSites500Response) GetError() string

GetError returns the Error field value if set, zero value otherwise.

func (*ListSites500Response) GetErrorOk

func (o *ListSites500Response) GetErrorOk() (*string, bool)

GetErrorOk returns a tuple with the Error field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ListSites500Response) GetMessage

func (o *ListSites500Response) GetMessage() string

GetMessage returns the Message field value if set, zero value otherwise.

func (*ListSites500Response) GetMessageOk

func (o *ListSites500Response) GetMessageOk() (*string, bool)

GetMessageOk returns a tuple with the Message field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ListSites500Response) GetStatusCode

func (o *ListSites500Response) GetStatusCode() int64

GetStatusCode returns the StatusCode field value if set, zero value otherwise.

func (*ListSites500Response) GetStatusCodeOk

func (o *ListSites500Response) GetStatusCodeOk() (*int64, bool)

GetStatusCodeOk returns a tuple with the StatusCode field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ListSites500Response) HasError

func (o *ListSites500Response) HasError() bool

HasError returns a boolean if a field has been set.

func (*ListSites500Response) HasMessage

func (o *ListSites500Response) HasMessage() bool

HasMessage returns a boolean if a field has been set.

func (*ListSites500Response) HasStatusCode

func (o *ListSites500Response) HasStatusCode() bool

HasStatusCode returns a boolean if a field has been set.

func (ListSites500Response) MarshalJSON

func (o ListSites500Response) MarshalJSON() ([]byte, error)

func (*ListSites500Response) SetError

func (o *ListSites500Response) SetError(v string)

SetError gets a reference to the given string and assigns it to the Error field.

func (*ListSites500Response) SetMessage

func (o *ListSites500Response) SetMessage(v string)

SetMessage gets a reference to the given string and assigns it to the Message field.

func (*ListSites500Response) SetStatusCode

func (o *ListSites500Response) SetStatusCode(v int64)

SetStatusCode gets a reference to the given int64 and assigns it to the StatusCode field.

func (ListSites500Response) ToMap

func (o ListSites500Response) ToMap() (map[string]interface{}, error)

func (*ListSites500Response) UnmarshalJSON

func (o *ListSites500Response) UnmarshalJSON(data []byte) (err error)

type MappedNullable

type MappedNullable interface {
	ToMap() (map[string]interface{}, error)
}

type NullableBool

type NullableBool struct {
	// contains filtered or unexported fields
}

func NewNullableBool

func NewNullableBool(val *bool) *NullableBool

func (NullableBool) Get

func (v NullableBool) Get() *bool

func (NullableBool) IsSet

func (v NullableBool) IsSet() bool

func (NullableBool) MarshalJSON

func (v NullableBool) MarshalJSON() ([]byte, error)

func (*NullableBool) Set

func (v *NullableBool) Set(val *bool)

func (*NullableBool) UnmarshalJSON

func (v *NullableBool) UnmarshalJSON(src []byte) error

func (*NullableBool) Unset

func (v *NullableBool) Unset()

type NullableCreateSiteRequest

type NullableCreateSiteRequest struct {
	// contains filtered or unexported fields
}

func NewNullableCreateSiteRequest

func NewNullableCreateSiteRequest(val *CreateSiteRequest) *NullableCreateSiteRequest

func (NullableCreateSiteRequest) Get

func (NullableCreateSiteRequest) IsSet

func (v NullableCreateSiteRequest) IsSet() bool

func (NullableCreateSiteRequest) MarshalJSON

func (v NullableCreateSiteRequest) MarshalJSON() ([]byte, error)

func (*NullableCreateSiteRequest) Set

func (*NullableCreateSiteRequest) UnmarshalJSON

func (v *NullableCreateSiteRequest) UnmarshalJSON(src []byte) error

func (*NullableCreateSiteRequest) Unset

func (v *NullableCreateSiteRequest) Unset()

type NullableFloat32

type NullableFloat32 struct {
	// contains filtered or unexported fields
}

func NewNullableFloat32

func NewNullableFloat32(val *float32) *NullableFloat32

func (NullableFloat32) Get

func (v NullableFloat32) Get() *float32

func (NullableFloat32) IsSet

func (v NullableFloat32) IsSet() bool

func (NullableFloat32) MarshalJSON

func (v NullableFloat32) MarshalJSON() ([]byte, error)

func (*NullableFloat32) Set

func (v *NullableFloat32) Set(val *float32)

func (*NullableFloat32) UnmarshalJSON

func (v *NullableFloat32) UnmarshalJSON(src []byte) error

func (*NullableFloat32) Unset

func (v *NullableFloat32) Unset()

type NullableFloat64

type NullableFloat64 struct {
	// contains filtered or unexported fields
}

func NewNullableFloat64

func NewNullableFloat64(val *float64) *NullableFloat64

func (NullableFloat64) Get

func (v NullableFloat64) Get() *float64

func (NullableFloat64) IsSet

func (v NullableFloat64) IsSet() bool

func (NullableFloat64) MarshalJSON

func (v NullableFloat64) MarshalJSON() ([]byte, error)

func (*NullableFloat64) Set

func (v *NullableFloat64) Set(val *float64)

func (*NullableFloat64) UnmarshalJSON

func (v *NullableFloat64) UnmarshalJSON(src []byte) error

func (*NullableFloat64) Unset

func (v *NullableFloat64) Unset()

type NullableInt

type NullableInt struct {
	// contains filtered or unexported fields
}

func NewNullableInt

func NewNullableInt(val *int) *NullableInt

func (NullableInt) Get

func (v NullableInt) Get() *int

func (NullableInt) IsSet

func (v NullableInt) IsSet() bool

func (NullableInt) MarshalJSON

func (v NullableInt) MarshalJSON() ([]byte, error)

func (*NullableInt) Set

func (v *NullableInt) Set(val *int)

func (*NullableInt) UnmarshalJSON

func (v *NullableInt) UnmarshalJSON(src []byte) error

func (*NullableInt) Unset

func (v *NullableInt) Unset()

type NullableInt32

type NullableInt32 struct {
	// contains filtered or unexported fields
}

func NewNullableInt32

func NewNullableInt32(val *int32) *NullableInt32

func (NullableInt32) Get

func (v NullableInt32) Get() *int32

func (NullableInt32) IsSet

func (v NullableInt32) IsSet() bool

func (NullableInt32) MarshalJSON

func (v NullableInt32) MarshalJSON() ([]byte, error)

func (*NullableInt32) Set

func (v *NullableInt32) Set(val *int32)

func (*NullableInt32) UnmarshalJSON

func (v *NullableInt32) UnmarshalJSON(src []byte) error

func (*NullableInt32) Unset

func (v *NullableInt32) Unset()

type NullableInt64

type NullableInt64 struct {
	// contains filtered or unexported fields
}

func NewNullableInt64

func NewNullableInt64(val *int64) *NullableInt64

func (NullableInt64) Get

func (v NullableInt64) Get() *int64

func (NullableInt64) IsSet

func (v NullableInt64) IsSet() bool

func (NullableInt64) MarshalJSON

func (v NullableInt64) MarshalJSON() ([]byte, error)

func (*NullableInt64) Set

func (v *NullableInt64) Set(val *int64)

func (*NullableInt64) UnmarshalJSON

func (v *NullableInt64) UnmarshalJSON(src []byte) error

func (*NullableInt64) Unset

func (v *NullableInt64) Unset()

type NullableListSites400Response

type NullableListSites400Response struct {
	// contains filtered or unexported fields
}

func NewNullableListSites400Response

func NewNullableListSites400Response(val *ListSites400Response) *NullableListSites400Response

func (NullableListSites400Response) Get

func (NullableListSites400Response) IsSet

func (NullableListSites400Response) MarshalJSON

func (v NullableListSites400Response) MarshalJSON() ([]byte, error)

func (*NullableListSites400Response) Set

func (*NullableListSites400Response) UnmarshalJSON

func (v *NullableListSites400Response) UnmarshalJSON(src []byte) error

func (*NullableListSites400Response) Unset

func (v *NullableListSites400Response) Unset()

type NullableListSites401Response

type NullableListSites401Response struct {
	// contains filtered or unexported fields
}

func NewNullableListSites401Response

func NewNullableListSites401Response(val *ListSites401Response) *NullableListSites401Response

func (NullableListSites401Response) Get

func (NullableListSites401Response) IsSet

func (NullableListSites401Response) MarshalJSON

func (v NullableListSites401Response) MarshalJSON() ([]byte, error)

func (*NullableListSites401Response) Set

func (*NullableListSites401Response) UnmarshalJSON

func (v *NullableListSites401Response) UnmarshalJSON(src []byte) error

func (*NullableListSites401Response) Unset

func (v *NullableListSites401Response) Unset()

type NullableListSites403Response

type NullableListSites403Response struct {
	// contains filtered or unexported fields
}

func NewNullableListSites403Response

func NewNullableListSites403Response(val *ListSites403Response) *NullableListSites403Response

func (NullableListSites403Response) Get

func (NullableListSites403Response) IsSet

func (NullableListSites403Response) MarshalJSON

func (v NullableListSites403Response) MarshalJSON() ([]byte, error)

func (*NullableListSites403Response) Set

func (*NullableListSites403Response) UnmarshalJSON

func (v *NullableListSites403Response) UnmarshalJSON(src []byte) error

func (*NullableListSites403Response) Unset

func (v *NullableListSites403Response) Unset()

type NullableListSites404Response

type NullableListSites404Response struct {
	// contains filtered or unexported fields
}

func NewNullableListSites404Response

func NewNullableListSites404Response(val *ListSites404Response) *NullableListSites404Response

func (NullableListSites404Response) Get

func (NullableListSites404Response) IsSet

func (NullableListSites404Response) MarshalJSON

func (v NullableListSites404Response) MarshalJSON() ([]byte, error)

func (*NullableListSites404Response) Set

func (*NullableListSites404Response) UnmarshalJSON

func (v *NullableListSites404Response) UnmarshalJSON(src []byte) error

func (*NullableListSites404Response) Unset

func (v *NullableListSites404Response) Unset()

type NullableListSites500Response

type NullableListSites500Response struct {
	// contains filtered or unexported fields
}

func NewNullableListSites500Response

func NewNullableListSites500Response(val *ListSites500Response) *NullableListSites500Response

func (NullableListSites500Response) Get

func (NullableListSites500Response) IsSet

func (NullableListSites500Response) MarshalJSON

func (v NullableListSites500Response) MarshalJSON() ([]byte, error)

func (*NullableListSites500Response) Set

func (*NullableListSites500Response) UnmarshalJSON

func (v *NullableListSites500Response) UnmarshalJSON(src []byte) error

func (*NullableListSites500Response) Unset

func (v *NullableListSites500Response) Unset()

type NullableSiteObject

type NullableSiteObject struct {
	// contains filtered or unexported fields
}

func NewNullableSiteObject

func NewNullableSiteObject(val *SiteObject) *NullableSiteObject

func (NullableSiteObject) Get

func (v NullableSiteObject) Get() *SiteObject

func (NullableSiteObject) IsSet

func (v NullableSiteObject) IsSet() bool

func (NullableSiteObject) MarshalJSON

func (v NullableSiteObject) MarshalJSON() ([]byte, error)

func (*NullableSiteObject) Set

func (v *NullableSiteObject) Set(val *SiteObject)

func (*NullableSiteObject) UnmarshalJSON

func (v *NullableSiteObject) UnmarshalJSON(src []byte) error

func (*NullableSiteObject) Unset

func (v *NullableSiteObject) Unset()

type NullableString

type NullableString struct {
	// contains filtered or unexported fields
}

func NewNullableString

func NewNullableString(val *string) *NullableString

func (NullableString) Get

func (v NullableString) Get() *string

func (NullableString) IsSet

func (v NullableString) IsSet() bool

func (NullableString) MarshalJSON

func (v NullableString) MarshalJSON() ([]byte, error)

func (*NullableString) Set

func (v *NullableString) Set(val *string)

func (*NullableString) UnmarshalJSON

func (v *NullableString) UnmarshalJSON(src []byte) error

func (*NullableString) Unset

func (v *NullableString) Unset()

type NullableTime

type NullableTime struct {
	// contains filtered or unexported fields
}

func NewNullableTime

func NewNullableTime(val *time.Time) *NullableTime

func (NullableTime) Get

func (v NullableTime) Get() *time.Time

func (NullableTime) IsSet

func (v NullableTime) IsSet() bool

func (NullableTime) MarshalJSON

func (v NullableTime) MarshalJSON() ([]byte, error)

func (*NullableTime) Set

func (v *NullableTime) Set(val *time.Time)

func (*NullableTime) UnmarshalJSON

func (v *NullableTime) UnmarshalJSON(src []byte) error

func (*NullableTime) Unset

func (v *NullableTime) Unset()

type ServerConfiguration

type ServerConfiguration struct {
	URL         string
	Description string
	Variables   map[string]ServerVariable
}

ServerConfiguration stores the information about a server

type ServerConfigurations

type ServerConfigurations []ServerConfiguration

ServerConfigurations stores multiple ServerConfiguration items

func (ServerConfigurations) URL

func (sc ServerConfigurations) URL(index int, variables map[string]string) (string, error)

URL formats template on a index using given variables

type ServerVariable

type ServerVariable struct {
	Description  string
	DefaultValue string
	EnumValues   []string
}

ServerVariable stores the information about a server variable

type SiteObject

type SiteObject struct {
	// The origin ID of the Site.
	OriginId int64 `json:"originId"`
	// The name of the Site. The name is a sequence of 1–255 characters.
	Name string `json:"name"`
	// The ID of the Site.
	SiteId int64 `json:"siteId"`
	// Specifies whether the Site is the default Site.
	IsDefault bool `json:"isDefault"`
	// The type of the Site.
	Type *string `json:"type,omitempty"`
	// The number of internal networks that are associated with the Site.
	InternalNetworkCount *int64 `json:"internalNetworkCount,omitempty"`
	// The number of virtual appliances that are associated with the Site.
	VaCount *int64 `json:"vaCount,omitempty"`
	// The date and time (ISO 8601 timestamp) when the Site was created.
	CreatedAt time.Time `json:"createdAt"`
	// The date and time (ISO 8601 timestamp) when the Site was modified.
	ModifiedAt           time.Time `json:"modifiedAt"`
	AdditionalProperties map[string]interface{}
}

SiteObject struct for SiteObject

func NewSiteObject

func NewSiteObject(originId int64, name string, siteId int64, isDefault bool, createdAt time.Time, modifiedAt time.Time) *SiteObject

NewSiteObject instantiates a new SiteObject object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewSiteObjectWithDefaults

func NewSiteObjectWithDefaults() *SiteObject

NewSiteObjectWithDefaults instantiates a new SiteObject object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*SiteObject) GetCreatedAt

func (o *SiteObject) GetCreatedAt() time.Time

GetCreatedAt returns the CreatedAt field value

func (*SiteObject) GetCreatedAtOk

func (o *SiteObject) GetCreatedAtOk() (*time.Time, bool)

GetCreatedAtOk returns a tuple with the CreatedAt field value and a boolean to check if the value has been set.

func (*SiteObject) GetInternalNetworkCount

func (o *SiteObject) GetInternalNetworkCount() int64

GetInternalNetworkCount returns the InternalNetworkCount field value if set, zero value otherwise.

func (*SiteObject) GetInternalNetworkCountOk

func (o *SiteObject) GetInternalNetworkCountOk() (*int64, bool)

GetInternalNetworkCountOk returns a tuple with the InternalNetworkCount field value if set, nil otherwise and a boolean to check if the value has been set.

func (*SiteObject) GetIsDefault

func (o *SiteObject) GetIsDefault() bool

GetIsDefault returns the IsDefault field value

func (*SiteObject) GetIsDefaultOk

func (o *SiteObject) GetIsDefaultOk() (*bool, bool)

GetIsDefaultOk returns a tuple with the IsDefault field value and a boolean to check if the value has been set.

func (*SiteObject) GetModifiedAt

func (o *SiteObject) GetModifiedAt() time.Time

GetModifiedAt returns the ModifiedAt field value

func (*SiteObject) GetModifiedAtOk

func (o *SiteObject) GetModifiedAtOk() (*time.Time, bool)

GetModifiedAtOk returns a tuple with the ModifiedAt field value and a boolean to check if the value has been set.

func (*SiteObject) GetName

func (o *SiteObject) GetName() string

GetName returns the Name field value

func (*SiteObject) GetNameOk

func (o *SiteObject) GetNameOk() (*string, bool)

GetNameOk returns a tuple with the Name field value and a boolean to check if the value has been set.

func (*SiteObject) GetOriginId

func (o *SiteObject) GetOriginId() int64

GetOriginId returns the OriginId field value

func (*SiteObject) GetOriginIdOk

func (o *SiteObject) GetOriginIdOk() (*int64, bool)

GetOriginIdOk returns a tuple with the OriginId field value and a boolean to check if the value has been set.

func (*SiteObject) GetSiteId

func (o *SiteObject) GetSiteId() int64

GetSiteId returns the SiteId field value

func (*SiteObject) GetSiteIdOk

func (o *SiteObject) GetSiteIdOk() (*int64, bool)

GetSiteIdOk returns a tuple with the SiteId field value and a boolean to check if the value has been set.

func (*SiteObject) GetType

func (o *SiteObject) GetType() string

GetType returns the Type field value if set, zero value otherwise.

func (*SiteObject) GetTypeOk

func (o *SiteObject) GetTypeOk() (*string, bool)

GetTypeOk returns a tuple with the Type field value if set, nil otherwise and a boolean to check if the value has been set.

func (*SiteObject) GetVaCount

func (o *SiteObject) GetVaCount() int64

GetVaCount returns the VaCount field value if set, zero value otherwise.

func (*SiteObject) GetVaCountOk

func (o *SiteObject) GetVaCountOk() (*int64, bool)

GetVaCountOk returns a tuple with the VaCount field value if set, nil otherwise and a boolean to check if the value has been set.

func (*SiteObject) HasInternalNetworkCount

func (o *SiteObject) HasInternalNetworkCount() bool

HasInternalNetworkCount returns a boolean if a field has been set.

func (*SiteObject) HasType

func (o *SiteObject) HasType() bool

HasType returns a boolean if a field has been set.

func (*SiteObject) HasVaCount

func (o *SiteObject) HasVaCount() bool

HasVaCount returns a boolean if a field has been set.

func (SiteObject) MarshalJSON

func (o SiteObject) MarshalJSON() ([]byte, error)

func (*SiteObject) SetCreatedAt

func (o *SiteObject) SetCreatedAt(v time.Time)

SetCreatedAt sets field value

func (*SiteObject) SetInternalNetworkCount

func (o *SiteObject) SetInternalNetworkCount(v int64)

SetInternalNetworkCount gets a reference to the given int64 and assigns it to the InternalNetworkCount field.

func (*SiteObject) SetIsDefault

func (o *SiteObject) SetIsDefault(v bool)

SetIsDefault sets field value

func (*SiteObject) SetModifiedAt

func (o *SiteObject) SetModifiedAt(v time.Time)

SetModifiedAt sets field value

func (*SiteObject) SetName

func (o *SiteObject) SetName(v string)

SetName sets field value

func (*SiteObject) SetOriginId

func (o *SiteObject) SetOriginId(v int64)

SetOriginId sets field value

func (*SiteObject) SetSiteId

func (o *SiteObject) SetSiteId(v int64)

SetSiteId sets field value

func (*SiteObject) SetType

func (o *SiteObject) SetType(v string)

SetType gets a reference to the given string and assigns it to the Type field.

func (*SiteObject) SetVaCount

func (o *SiteObject) SetVaCount(v int64)

SetVaCount gets a reference to the given int64 and assigns it to the VaCount field.

func (SiteObject) ToMap

func (o SiteObject) ToMap() (map[string]interface{}, error)

func (*SiteObject) UnmarshalJSON

func (o *SiteObject) UnmarshalJSON(data []byte) (err error)

type SitesAPIService

type SitesAPIService service

SitesAPIService SitesAPI service

func (*SitesAPIService) CreateSite

CreateSite Create Site

Create a Site in the organization.

@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
@return ApiCreateSiteRequest

func (*SitesAPIService) CreateSiteExecute

func (a *SitesAPIService) CreateSiteExecute(r ApiCreateSiteRequest) (*SiteObject, *http.Response, error)

Execute executes the request

@return SiteObject

func (*SitesAPIService) DeleteSite

func (a *SitesAPIService) DeleteSite(ctx context.Context, siteId int64) ApiDeleteSiteRequest

DeleteSite Delete Site

Delete a Site in the organization.

@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
@param siteId The ID of the Site.
@return ApiDeleteSiteRequest

func (*SitesAPIService) DeleteSiteExecute

func (a *SitesAPIService) DeleteSiteExecute(r ApiDeleteSiteRequest) (*http.Response, error)

Execute executes the request

func (*SitesAPIService) GetSite

func (a *SitesAPIService) GetSite(ctx context.Context, siteId int64) ApiGetSiteRequest

GetSite Get Site

Get a Site in the organization.

@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
@param siteId The ID of the Site.
@return ApiGetSiteRequest

func (*SitesAPIService) GetSiteExecute

func (a *SitesAPIService) GetSiteExecute(r ApiGetSiteRequest) (*SiteObject, *http.Response, error)

Execute executes the request

@return SiteObject

func (*SitesAPIService) ListSites

ListSites List Sites

List the Sites in the organization.

@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
@return ApiListSitesRequest

func (*SitesAPIService) ListSitesExecute

func (a *SitesAPIService) ListSitesExecute(r ApiListSitesRequest) ([]SiteObject, *http.Response, error)

Execute executes the request

@return []SiteObject

func (*SitesAPIService) UpdateSite

func (a *SitesAPIService) UpdateSite(ctx context.Context, siteId int64) ApiUpdateSiteRequest

UpdateSite Update Site

Update a Site in the organization.

@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
@param siteId The ID of the Site.
@return ApiUpdateSiteRequest

func (*SitesAPIService) UpdateSiteExecute

func (a *SitesAPIService) UpdateSiteExecute(r ApiUpdateSiteRequest) (*SiteObject, *http.Response, error)

Execute executes the request

@return SiteObject

Jump to