swg

package
v1.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 5, 2026 License: Apache-2.0 Imports: 21 Imported by: 0

README

Go API client for swg

Manage the Secure Access Secure Web Gateway (SWG) settings for the devices in an organization.

Overview

This API client was generated by the OpenAPI Generator project. By using the OpenAPI-spec from a remote server, you can easily generate an API client.

  • API version: 2.0.0
  • Package version: 1.0.0
  • Generator version: 7.21.0-SNAPSHOT
  • Build package: org.openapitools.codegen.languages.GoClientCodegen

Installation

Import the package in a go file in your project and run go mod tidy:

import swg "github.com/CiscoDevNet/go-ciscosecureaccess/swg"

To use a proxy, set the environment variable HTTP_PROXY:

os.Setenv("HTTP_PROXY", "http://proxy_name:proxy_port")

Configuration of Server URL

Default configuration comes with Servers field that contains server objects as defined in the OpenAPI specification.

Select Server Configuration

For using other server than the one defined on index 0 set context value swg.ContextServerIndex of type int.

ctx := context.WithValue(context.Background(), swg.ContextServerIndex, 1)
Templated Server URL

Templated server URL is formatted using default variables from configuration or from context value swg.ContextServerVariables of type map[string]string.

ctx := context.WithValue(context.Background(), swg.ContextServerVariables, map[string]string{
	"basePath": "v2",
})

Note, enum values are always validated and all unused variables are silently ignored.

URLs Configuration per Operation

Each operation can use different server URL defined using OperationServers map in the Configuration. An operation is uniquely identified by "{classname}Service.{nickname}" string. Similar rules for overriding default operation server index and variables applies by using swg.ContextOperationServerIndices and swg.ContextOperationServerVariables context maps.

ctx := context.WithValue(context.Background(), swg.ContextOperationServerIndices, map[string]int{
	"{classname}Service.{nickname}": 2,
})
ctx = context.WithValue(context.Background(), swg.ContextOperationServerVariables, map[string]map[string]string{
	"{classname}Service.{nickname}": {
		"port": "8443",
	},
})

Documentation for API Endpoints

All URIs are relative to https://api.sse.cisco.com/deployments/v2

Class Method HTTP request Description
SWGDeviceSettingsAPI CreateSecureWebGatewayDeviceSettings Post /deviceSettings/SWGEnabled/set Set SWG Override Device Settings
SWGDeviceSettingsAPI DeleteSecureWebGatewayDeviceSettings Post /deviceSettings/SWGEnabled/remove Delete SWG Override Device Settings
SWGDeviceSettingsAPI ListSecureWebGatewayDeviceSettings Post /deviceSettings/SWGEnabled/list List SWG Override Device Settings

Documentation For Models

Documentation For Authorization

Authentication schemes defined for the API:

oauthFlow
  • Type: OAuth
  • Flow: application
  • Authorization URL:
  • Scopes:
  • deployments.devices.swg:write: Write SWG device settings
  • deployments.devices.swg:read: Read SWG device settings

Example

auth := context.WithValue(context.Background(), swg.ContextAccessToken, "ACCESSTOKENSTRING")
r, err := client.Service.Operation(auth, args)

Or via OAuth2 module to automatically refresh tokens and perform user authentication.

import "golang.org/x/oauth2"

/* Perform OAuth2 round trip request and obtain a token */

tokenSource := oauth2cfg.TokenSource(createContext(httpClient), &token)
auth := context.WithValue(oauth2.NoContext, swg.ContextOAuth2, tokenSource)
r, err := client.Service.Operation(auth, args)

Documentation for Utility Methods

Due to the fact that model structure members are all pointers, this package contains a number of utility functions to easily obtain pointers to values of basic types. Each of these functions takes a value of the given basic type and returns a pointer to it:

  • PtrBool
  • PtrInt
  • PtrInt32
  • PtrInt64
  • PtrFloat
  • PtrFloat32
  • PtrFloat64
  • PtrString
  • PtrTime

Author

Documentation

Index

Constants

This section is empty.

Variables

var (
	JsonCheck = regexp.MustCompile(`(?i:(?:application|text)/(?:[^;]+\+)?json)`)
	XmlCheck  = regexp.MustCompile(`(?i:(?:application|text)/(?:[^;]+\+)?xml)`)
)
var (
	// ContextOAuth2 takes an oauth2.TokenSource as authentication for the request.
	ContextOAuth2 = contextKey("token")

	// ContextServerIndex uses a server configuration from the index.
	ContextServerIndex = contextKey("serverIndex")

	// ContextOperationServerIndices uses a server configuration from the index mapping.
	ContextOperationServerIndices = contextKey("serverOperationIndices")

	// ContextServerVariables overrides a server configuration variables.
	ContextServerVariables = contextKey("serverVariables")

	// ContextOperationServerVariables overrides a server configuration variables using operation specific values.
	ContextOperationServerVariables = contextKey("serverOperationVariables")
)
var AllowedValueEnumValues = []Value{
	"0",
	"1",
}

All allowed values of Value enum

Functions

func CacheExpires

func CacheExpires(r *http.Response) time.Time

CacheExpires helper function to determine remaining time before repeating a request.

func IsNil

func IsNil(i interface{}) bool

IsNil checks if an input is nil

func PtrBool

func PtrBool(v bool) *bool

PtrBool is a helper routine that returns a pointer to given boolean value.

func PtrFloat32

func PtrFloat32(v float32) *float32

PtrFloat32 is a helper routine that returns a pointer to given float value.

func PtrFloat64

func PtrFloat64(v float64) *float64

PtrFloat64 is a helper routine that returns a pointer to given float value.

func PtrInt

func PtrInt(v int) *int

PtrInt is a helper routine that returns a pointer to given integer value.

func PtrInt32

func PtrInt32(v int32) *int32

PtrInt32 is a helper routine that returns a pointer to given integer value.

func PtrInt64

func PtrInt64(v int64) *int64

PtrInt64 is a helper routine that returns a pointer to given integer value.

func PtrString

func PtrString(v string) *string

PtrString is a helper routine that returns a pointer to given string value.

func PtrTime

func PtrTime(v time.Time) *time.Time

PtrTime is helper routine that returns a pointer to given Time value.

Types

type APIClient

type APIClient struct {
	SWGDeviceSettingsAPI *SWGDeviceSettingsAPIService
	// contains filtered or unexported fields
}

APIClient manages communication with the Cisco Secure Web Gateway Device Settings API API v2.0.0 In most cases there should be only one, shared, APIClient.

func NewAPIClient

func NewAPIClient(cfg *Configuration) *APIClient

NewAPIClient creates a new API client. Requires a userAgent string describing your application. optionally a custom http.Client to allow for advanced features such as caching.

func (*APIClient) GetConfig

func (c *APIClient) GetConfig() *Configuration

Allow modification of underlying config for alternate implementations and testing Caution: modifying the configuration while live can cause data races and potentially unwanted behavior

type APIKey

type APIKey struct {
	Key    string
	Prefix string
}

APIKey provides API key based authentication to a request passed via context using ContextAPIKey

type APIResponse

type APIResponse struct {
	*http.Response `json:"-"`
	Message        string `json:"message,omitempty"`
	// Operation is the name of the OpenAPI operation.
	Operation string `json:"operation,omitempty"`
	// RequestURL is the request URL. This value is always available, even if the
	// embedded *http.Response is nil.
	RequestURL string `json:"url,omitempty"`
	// Method is the HTTP method used for the request.  This value is always
	// available, even if the embedded *http.Response is nil.
	Method string `json:"method,omitempty"`
	// Payload holds the contents of the response body (which may be nil or empty).
	// This is provided here as the raw response.Body() reader will have already
	// been drained.
	Payload []byte `json:"-"`
}

APIResponse stores the API response returned by the server.

func NewAPIResponse

func NewAPIResponse(r *http.Response) *APIResponse

NewAPIResponse returns a new APIResponse object.

func NewAPIResponseWithError

func NewAPIResponseWithError(errorMessage string) *APIResponse

NewAPIResponseWithError returns a new APIResponse object with the provided error message.

type ApiCreateSecureWebGatewayDeviceSettingsRequest

type ApiCreateSecureWebGatewayDeviceSettingsRequest struct {
	ApiService *SWGDeviceSettingsAPIService
	// contains filtered or unexported fields
}

func (ApiCreateSecureWebGatewayDeviceSettingsRequest) CreateSecureWebGatewayDeviceSettingsRequest

func (r ApiCreateSecureWebGatewayDeviceSettingsRequest) CreateSecureWebGatewayDeviceSettingsRequest(createSecureWebGatewayDeviceSettingsRequest CreateSecureWebGatewayDeviceSettingsRequest) ApiCreateSecureWebGatewayDeviceSettingsRequest

* Provide a list of origin ID for the devices in the organization. The list can contain 1–100 origin IDs. * Provide the Secure Web gateway (SWG) device setting to apply to the devices.

func (ApiCreateSecureWebGatewayDeviceSettingsRequest) Execute

type ApiDeleteSecureWebGatewayDeviceSettingsRequest

type ApiDeleteSecureWebGatewayDeviceSettingsRequest struct {
	ApiService *SWGDeviceSettingsAPIService
	// contains filtered or unexported fields
}

func (ApiDeleteSecureWebGatewayDeviceSettingsRequest) Execute

func (ApiDeleteSecureWebGatewayDeviceSettingsRequest) ListSecureWebGatewayDeviceSettingsRequest

func (r ApiDeleteSecureWebGatewayDeviceSettingsRequest) ListSecureWebGatewayDeviceSettingsRequest(listSecureWebGatewayDeviceSettingsRequest ListSecureWebGatewayDeviceSettingsRequest) ApiDeleteSecureWebGatewayDeviceSettingsRequest

Provide a list of origin ID for the devices in the organization. The list can contain 1–100 origin IDs.

type ApiListSecureWebGatewayDeviceSettingsRequest

type ApiListSecureWebGatewayDeviceSettingsRequest struct {
	ApiService *SWGDeviceSettingsAPIService
	// contains filtered or unexported fields
}

func (ApiListSecureWebGatewayDeviceSettingsRequest) Execute

func (ApiListSecureWebGatewayDeviceSettingsRequest) ListSecureWebGatewayDeviceSettingsRequest

func (r ApiListSecureWebGatewayDeviceSettingsRequest) ListSecureWebGatewayDeviceSettingsRequest(listSecureWebGatewayDeviceSettingsRequest ListSecureWebGatewayDeviceSettingsRequest) ApiListSecureWebGatewayDeviceSettingsRequest

Provide a list of origin ID for the devices in the organization. The list can contain 1–100 origin IDs.

type BasicAuth

type BasicAuth struct {
	UserName string `json:"userName,omitempty"`
	Password string `json:"password,omitempty"`
}

BasicAuth provides basic http authentication to a request passed via context using ContextBasicAuth

type Configuration

type Configuration struct {
	Host             string            `json:"host,omitempty"`
	Scheme           string            `json:"scheme,omitempty"`
	DefaultHeader    map[string]string `json:"defaultHeader,omitempty"`
	UserAgent        string            `json:"userAgent,omitempty"`
	Debug            bool              `json:"debug,omitempty"`
	Servers          ServerConfigurations
	OperationServers map[string]ServerConfigurations
	HTTPClient       *http.Client
}

Configuration stores the configuration of the API client

func NewConfiguration

func NewConfiguration() *Configuration

NewConfiguration returns a new Configuration object

func (*Configuration) AddDefaultHeader

func (c *Configuration) AddDefaultHeader(key string, value string)

AddDefaultHeader adds a new HTTP header to the default header in the request

func (*Configuration) ServerURL

func (c *Configuration) ServerURL(index int, variables map[string]string) (string, error)

ServerURL returns URL based on server settings

func (*Configuration) ServerURLWithContext

func (c *Configuration) ServerURLWithContext(ctx context.Context, endpoint string) (string, error)

ServerURLWithContext returns a new server URL given an endpoint

type CreateSecureWebGatewayDeviceSettings400Response

type CreateSecureWebGatewayDeviceSettings400Response struct {
	// The message associated with the error condition.
	Error                string `json:"Error"`
	AdditionalProperties map[string]interface{}
}

CreateSecureWebGatewayDeviceSettings400Response The information about the error condition.

func NewCreateSecureWebGatewayDeviceSettings400Response

func NewCreateSecureWebGatewayDeviceSettings400Response(error_ string) *CreateSecureWebGatewayDeviceSettings400Response

NewCreateSecureWebGatewayDeviceSettings400Response instantiates a new CreateSecureWebGatewayDeviceSettings400Response object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewCreateSecureWebGatewayDeviceSettings400ResponseWithDefaults

func NewCreateSecureWebGatewayDeviceSettings400ResponseWithDefaults() *CreateSecureWebGatewayDeviceSettings400Response

NewCreateSecureWebGatewayDeviceSettings400ResponseWithDefaults instantiates a new CreateSecureWebGatewayDeviceSettings400Response object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*CreateSecureWebGatewayDeviceSettings400Response) GetError

GetError returns the Error field value

func (*CreateSecureWebGatewayDeviceSettings400Response) GetErrorOk

GetErrorOk returns a tuple with the Error field value and a boolean to check if the value has been set.

func (CreateSecureWebGatewayDeviceSettings400Response) MarshalJSON

func (*CreateSecureWebGatewayDeviceSettings400Response) SetError

SetError sets field value

func (CreateSecureWebGatewayDeviceSettings400Response) ToMap

func (o CreateSecureWebGatewayDeviceSettings400Response) ToMap() (map[string]interface{}, error)

func (*CreateSecureWebGatewayDeviceSettings400Response) UnmarshalJSON

func (o *CreateSecureWebGatewayDeviceSettings400Response) UnmarshalJSON(data []byte) (err error)

type CreateSecureWebGatewayDeviceSettings413Response

type CreateSecureWebGatewayDeviceSettings413Response struct {
	// Invalid Request: orginIds in the request exceeded max limit - 100.
	Error                string `json:"Error"`
	AdditionalProperties map[string]interface{}
}

CreateSecureWebGatewayDeviceSettings413Response The list of `originIds` contains more than 100 origin IDs.

func NewCreateSecureWebGatewayDeviceSettings413Response

func NewCreateSecureWebGatewayDeviceSettings413Response(error_ string) *CreateSecureWebGatewayDeviceSettings413Response

NewCreateSecureWebGatewayDeviceSettings413Response instantiates a new CreateSecureWebGatewayDeviceSettings413Response object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewCreateSecureWebGatewayDeviceSettings413ResponseWithDefaults

func NewCreateSecureWebGatewayDeviceSettings413ResponseWithDefaults() *CreateSecureWebGatewayDeviceSettings413Response

NewCreateSecureWebGatewayDeviceSettings413ResponseWithDefaults instantiates a new CreateSecureWebGatewayDeviceSettings413Response object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*CreateSecureWebGatewayDeviceSettings413Response) GetError

GetError returns the Error field value

func (*CreateSecureWebGatewayDeviceSettings413Response) GetErrorOk

GetErrorOk returns a tuple with the Error field value and a boolean to check if the value has been set.

func (CreateSecureWebGatewayDeviceSettings413Response) MarshalJSON

func (*CreateSecureWebGatewayDeviceSettings413Response) SetError

SetError sets field value

func (CreateSecureWebGatewayDeviceSettings413Response) ToMap

func (o CreateSecureWebGatewayDeviceSettings413Response) ToMap() (map[string]interface{}, error)

func (*CreateSecureWebGatewayDeviceSettings413Response) UnmarshalJSON

func (o *CreateSecureWebGatewayDeviceSettings413Response) UnmarshalJSON(data []byte) (err error)

type CreateSecureWebGatewayDeviceSettingsRequest

type CreateSecureWebGatewayDeviceSettingsRequest struct {
	// The list of origin IDs. The list can contain 1–100 origin IDs.
	OriginIds            []int64 `json:"originIds"`
	Value                Value   `json:"value"`
	AdditionalProperties map[string]interface{}
}

CreateSecureWebGatewayDeviceSettingsRequest The properties of the `originIds` and `value` of the SWG device setting.

func NewCreateSecureWebGatewayDeviceSettingsRequest

func NewCreateSecureWebGatewayDeviceSettingsRequest(originIds []int64, value Value) *CreateSecureWebGatewayDeviceSettingsRequest

NewCreateSecureWebGatewayDeviceSettingsRequest instantiates a new CreateSecureWebGatewayDeviceSettingsRequest object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewCreateSecureWebGatewayDeviceSettingsRequestWithDefaults

func NewCreateSecureWebGatewayDeviceSettingsRequestWithDefaults() *CreateSecureWebGatewayDeviceSettingsRequest

NewCreateSecureWebGatewayDeviceSettingsRequestWithDefaults instantiates a new CreateSecureWebGatewayDeviceSettingsRequest object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*CreateSecureWebGatewayDeviceSettingsRequest) GetOriginIds

GetOriginIds returns the OriginIds field value

func (*CreateSecureWebGatewayDeviceSettingsRequest) GetOriginIdsOk

func (o *CreateSecureWebGatewayDeviceSettingsRequest) GetOriginIdsOk() ([]int64, bool)

GetOriginIdsOk returns a tuple with the OriginIds field value and a boolean to check if the value has been set.

func (*CreateSecureWebGatewayDeviceSettingsRequest) GetValue

GetValue returns the Value field value

func (*CreateSecureWebGatewayDeviceSettingsRequest) GetValueOk

GetValueOk returns a tuple with the Value field value and a boolean to check if the value has been set.

func (CreateSecureWebGatewayDeviceSettingsRequest) MarshalJSON

func (*CreateSecureWebGatewayDeviceSettingsRequest) SetOriginIds

SetOriginIds sets field value

func (*CreateSecureWebGatewayDeviceSettingsRequest) SetValue

SetValue sets field value

func (CreateSecureWebGatewayDeviceSettingsRequest) ToMap

func (o CreateSecureWebGatewayDeviceSettingsRequest) ToMap() (map[string]interface{}, error)

func (*CreateSecureWebGatewayDeviceSettingsRequest) UnmarshalJSON

func (o *CreateSecureWebGatewayDeviceSettingsRequest) UnmarshalJSON(data []byte) (err error)

type DeleteSecureWebGatewayDeviceSettings200Response

type DeleteSecureWebGatewayDeviceSettings200Response struct {
	// Deleted SWG override setting on the devices.
	Status               *string `json:"status,omitempty"`
	AdditionalProperties map[string]interface{}
}

DeleteSecureWebGatewayDeviceSettings200Response struct for DeleteSecureWebGatewayDeviceSettings200Response

func NewDeleteSecureWebGatewayDeviceSettings200Response

func NewDeleteSecureWebGatewayDeviceSettings200Response() *DeleteSecureWebGatewayDeviceSettings200Response

NewDeleteSecureWebGatewayDeviceSettings200Response instantiates a new DeleteSecureWebGatewayDeviceSettings200Response object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewDeleteSecureWebGatewayDeviceSettings200ResponseWithDefaults

func NewDeleteSecureWebGatewayDeviceSettings200ResponseWithDefaults() *DeleteSecureWebGatewayDeviceSettings200Response

NewDeleteSecureWebGatewayDeviceSettings200ResponseWithDefaults instantiates a new DeleteSecureWebGatewayDeviceSettings200Response object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*DeleteSecureWebGatewayDeviceSettings200Response) GetStatus

GetStatus returns the Status field value if set, zero value otherwise.

func (*DeleteSecureWebGatewayDeviceSettings200Response) GetStatusOk

GetStatusOk returns a tuple with the Status field value if set, nil otherwise and a boolean to check if the value has been set.

func (*DeleteSecureWebGatewayDeviceSettings200Response) HasStatus

HasStatus returns a boolean if a field has been set.

func (DeleteSecureWebGatewayDeviceSettings200Response) MarshalJSON

func (*DeleteSecureWebGatewayDeviceSettings200Response) SetStatus

SetStatus gets a reference to the given string and assigns it to the Status field.

func (DeleteSecureWebGatewayDeviceSettings200Response) ToMap

func (o DeleteSecureWebGatewayDeviceSettings200Response) ToMap() (map[string]interface{}, error)

func (*DeleteSecureWebGatewayDeviceSettings200Response) UnmarshalJSON

func (o *DeleteSecureWebGatewayDeviceSettings200Response) UnmarshalJSON(data []byte) (err error)

type GenericOpenAPIError

type GenericOpenAPIError struct {
	// contains filtered or unexported fields
}

GenericOpenAPIError Provides access to the body, error and model on returned errors.

func (GenericOpenAPIError) Body

func (e GenericOpenAPIError) Body() []byte

Body returns the raw bytes of the response

func (GenericOpenAPIError) Error

func (e GenericOpenAPIError) Error() string

Error returns non-empty string if there was an error.

func (GenericOpenAPIError) Model

func (e GenericOpenAPIError) Model() interface{}

Model returns the unpacked model of the error

type ListSWGDeviceSettingsInner

type ListSWGDeviceSettingsInner struct {
	// The origin ID of the device.
	OriginId int64 `json:"originId"`
	// The name of the device setting.
	Name  string `json:"name"`
	Value Value  `json:"value"`
	// The date and time when the settings on the device were modified. The timestamp is in the ISO 8601 date format.
	ModifiedAt           string `json:"modifiedAt"`
	AdditionalProperties map[string]interface{}
}

ListSWGDeviceSettingsInner The properties of the secure web gateway settings for the device.

func NewListSWGDeviceSettingsInner

func NewListSWGDeviceSettingsInner(originId int64, name string, value Value, modifiedAt string) *ListSWGDeviceSettingsInner

NewListSWGDeviceSettingsInner instantiates a new ListSWGDeviceSettingsInner object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewListSWGDeviceSettingsInnerWithDefaults

func NewListSWGDeviceSettingsInnerWithDefaults() *ListSWGDeviceSettingsInner

NewListSWGDeviceSettingsInnerWithDefaults instantiates a new ListSWGDeviceSettingsInner object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*ListSWGDeviceSettingsInner) GetModifiedAt

func (o *ListSWGDeviceSettingsInner) GetModifiedAt() string

GetModifiedAt returns the ModifiedAt field value

func (*ListSWGDeviceSettingsInner) GetModifiedAtOk

func (o *ListSWGDeviceSettingsInner) GetModifiedAtOk() (*string, bool)

GetModifiedAtOk returns a tuple with the ModifiedAt field value and a boolean to check if the value has been set.

func (*ListSWGDeviceSettingsInner) GetName

func (o *ListSWGDeviceSettingsInner) GetName() string

GetName returns the Name field value

func (*ListSWGDeviceSettingsInner) GetNameOk

func (o *ListSWGDeviceSettingsInner) GetNameOk() (*string, bool)

GetNameOk returns a tuple with the Name field value and a boolean to check if the value has been set.

func (*ListSWGDeviceSettingsInner) GetOriginId

func (o *ListSWGDeviceSettingsInner) GetOriginId() int64

GetOriginId returns the OriginId field value

func (*ListSWGDeviceSettingsInner) GetOriginIdOk

func (o *ListSWGDeviceSettingsInner) GetOriginIdOk() (*int64, bool)

GetOriginIdOk returns a tuple with the OriginId field value and a boolean to check if the value has been set.

func (*ListSWGDeviceSettingsInner) GetValue

func (o *ListSWGDeviceSettingsInner) GetValue() Value

GetValue returns the Value field value

func (*ListSWGDeviceSettingsInner) GetValueOk

func (o *ListSWGDeviceSettingsInner) GetValueOk() (*Value, bool)

GetValueOk returns a tuple with the Value field value and a boolean to check if the value has been set.

func (ListSWGDeviceSettingsInner) MarshalJSON

func (o ListSWGDeviceSettingsInner) MarshalJSON() ([]byte, error)

func (*ListSWGDeviceSettingsInner) SetModifiedAt

func (o *ListSWGDeviceSettingsInner) SetModifiedAt(v string)

SetModifiedAt sets field value

func (*ListSWGDeviceSettingsInner) SetName

func (o *ListSWGDeviceSettingsInner) SetName(v string)

SetName sets field value

func (*ListSWGDeviceSettingsInner) SetOriginId

func (o *ListSWGDeviceSettingsInner) SetOriginId(v int64)

SetOriginId sets field value

func (*ListSWGDeviceSettingsInner) SetValue

func (o *ListSWGDeviceSettingsInner) SetValue(v Value)

SetValue sets field value

func (ListSWGDeviceSettingsInner) ToMap

func (o ListSWGDeviceSettingsInner) ToMap() (map[string]interface{}, error)

func (*ListSWGDeviceSettingsInner) UnmarshalJSON

func (o *ListSWGDeviceSettingsInner) UnmarshalJSON(data []byte) (err error)

type ListSecureWebGatewayDeviceSettingsRequest

type ListSecureWebGatewayDeviceSettingsRequest struct {
	// The list of origin IDs. The list can contain 1–100 origin IDs.
	OriginIds            []int64 `json:"originIds"`
	AdditionalProperties map[string]interface{}
}

ListSecureWebGatewayDeviceSettingsRequest The `originIds` property.

func NewListSecureWebGatewayDeviceSettingsRequest

func NewListSecureWebGatewayDeviceSettingsRequest(originIds []int64) *ListSecureWebGatewayDeviceSettingsRequest

NewListSecureWebGatewayDeviceSettingsRequest instantiates a new ListSecureWebGatewayDeviceSettingsRequest object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewListSecureWebGatewayDeviceSettingsRequestWithDefaults

func NewListSecureWebGatewayDeviceSettingsRequestWithDefaults() *ListSecureWebGatewayDeviceSettingsRequest

NewListSecureWebGatewayDeviceSettingsRequestWithDefaults instantiates a new ListSecureWebGatewayDeviceSettingsRequest object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*ListSecureWebGatewayDeviceSettingsRequest) GetOriginIds

GetOriginIds returns the OriginIds field value

func (*ListSecureWebGatewayDeviceSettingsRequest) GetOriginIdsOk

func (o *ListSecureWebGatewayDeviceSettingsRequest) GetOriginIdsOk() ([]int64, bool)

GetOriginIdsOk returns a tuple with the OriginIds field value and a boolean to check if the value has been set.

func (ListSecureWebGatewayDeviceSettingsRequest) MarshalJSON

func (*ListSecureWebGatewayDeviceSettingsRequest) SetOriginIds

func (o *ListSecureWebGatewayDeviceSettingsRequest) SetOriginIds(v []int64)

SetOriginIds sets field value

func (ListSecureWebGatewayDeviceSettingsRequest) ToMap

func (o ListSecureWebGatewayDeviceSettingsRequest) ToMap() (map[string]interface{}, error)

func (*ListSecureWebGatewayDeviceSettingsRequest) UnmarshalJSON

func (o *ListSecureWebGatewayDeviceSettingsRequest) UnmarshalJSON(data []byte) (err error)

type MappedNullable

type MappedNullable interface {
	ToMap() (map[string]interface{}, error)
}

type ModelError

type ModelError struct {
	// The message associated with the error condition.
	Message *string `json:"message,omitempty"`
	// The status code for the error condition.
	Error                *string `json:"error,omitempty"`
	AdditionalProperties map[string]interface{}
}

ModelError The information about the error condition.

func NewModelError

func NewModelError() *ModelError

NewModelError instantiates a new ModelError object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewModelErrorWithDefaults

func NewModelErrorWithDefaults() *ModelError

NewModelErrorWithDefaults instantiates a new ModelError object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*ModelError) GetError

func (o *ModelError) GetError() string

GetError returns the Error field value if set, zero value otherwise.

func (*ModelError) GetErrorOk

func (o *ModelError) GetErrorOk() (*string, bool)

GetErrorOk returns a tuple with the Error field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ModelError) GetMessage

func (o *ModelError) GetMessage() string

GetMessage returns the Message field value if set, zero value otherwise.

func (*ModelError) GetMessageOk

func (o *ModelError) GetMessageOk() (*string, bool)

GetMessageOk returns a tuple with the Message field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ModelError) HasError

func (o *ModelError) HasError() bool

HasError returns a boolean if a field has been set.

func (*ModelError) HasMessage

func (o *ModelError) HasMessage() bool

HasMessage returns a boolean if a field has been set.

func (ModelError) MarshalJSON

func (o ModelError) MarshalJSON() ([]byte, error)

func (*ModelError) SetError

func (o *ModelError) SetError(v string)

SetError gets a reference to the given string and assigns it to the Error field.

func (*ModelError) SetMessage

func (o *ModelError) SetMessage(v string)

SetMessage gets a reference to the given string and assigns it to the Message field.

func (ModelError) ToMap

func (o ModelError) ToMap() (map[string]interface{}, error)

func (*ModelError) UnmarshalJSON

func (o *ModelError) UnmarshalJSON(data []byte) (err error)

type NullableBool

type NullableBool struct {
	// contains filtered or unexported fields
}

func NewNullableBool

func NewNullableBool(val *bool) *NullableBool

func (NullableBool) Get

func (v NullableBool) Get() *bool

func (NullableBool) IsSet

func (v NullableBool) IsSet() bool

func (NullableBool) MarshalJSON

func (v NullableBool) MarshalJSON() ([]byte, error)

func (*NullableBool) Set

func (v *NullableBool) Set(val *bool)

func (*NullableBool) UnmarshalJSON

func (v *NullableBool) UnmarshalJSON(src []byte) error

func (*NullableBool) Unset

func (v *NullableBool) Unset()

type NullableCreateSecureWebGatewayDeviceSettings400Response

type NullableCreateSecureWebGatewayDeviceSettings400Response struct {
	// contains filtered or unexported fields
}

func (NullableCreateSecureWebGatewayDeviceSettings400Response) Get

func (NullableCreateSecureWebGatewayDeviceSettings400Response) IsSet

func (NullableCreateSecureWebGatewayDeviceSettings400Response) MarshalJSON

func (*NullableCreateSecureWebGatewayDeviceSettings400Response) Set

func (*NullableCreateSecureWebGatewayDeviceSettings400Response) UnmarshalJSON

func (*NullableCreateSecureWebGatewayDeviceSettings400Response) Unset

type NullableCreateSecureWebGatewayDeviceSettings413Response

type NullableCreateSecureWebGatewayDeviceSettings413Response struct {
	// contains filtered or unexported fields
}

func (NullableCreateSecureWebGatewayDeviceSettings413Response) Get

func (NullableCreateSecureWebGatewayDeviceSettings413Response) IsSet

func (NullableCreateSecureWebGatewayDeviceSettings413Response) MarshalJSON

func (*NullableCreateSecureWebGatewayDeviceSettings413Response) Set

func (*NullableCreateSecureWebGatewayDeviceSettings413Response) UnmarshalJSON

func (*NullableCreateSecureWebGatewayDeviceSettings413Response) Unset

type NullableCreateSecureWebGatewayDeviceSettingsRequest

type NullableCreateSecureWebGatewayDeviceSettingsRequest struct {
	// contains filtered or unexported fields
}

func (NullableCreateSecureWebGatewayDeviceSettingsRequest) Get

func (NullableCreateSecureWebGatewayDeviceSettingsRequest) IsSet

func (NullableCreateSecureWebGatewayDeviceSettingsRequest) MarshalJSON

func (*NullableCreateSecureWebGatewayDeviceSettingsRequest) Set

func (*NullableCreateSecureWebGatewayDeviceSettingsRequest) UnmarshalJSON

func (*NullableCreateSecureWebGatewayDeviceSettingsRequest) Unset

type NullableDeleteSecureWebGatewayDeviceSettings200Response

type NullableDeleteSecureWebGatewayDeviceSettings200Response struct {
	// contains filtered or unexported fields
}

func (NullableDeleteSecureWebGatewayDeviceSettings200Response) Get

func (NullableDeleteSecureWebGatewayDeviceSettings200Response) IsSet

func (NullableDeleteSecureWebGatewayDeviceSettings200Response) MarshalJSON

func (*NullableDeleteSecureWebGatewayDeviceSettings200Response) Set

func (*NullableDeleteSecureWebGatewayDeviceSettings200Response) UnmarshalJSON

func (*NullableDeleteSecureWebGatewayDeviceSettings200Response) Unset

type NullableFloat32

type NullableFloat32 struct {
	// contains filtered or unexported fields
}

func NewNullableFloat32

func NewNullableFloat32(val *float32) *NullableFloat32

func (NullableFloat32) Get

func (v NullableFloat32) Get() *float32

func (NullableFloat32) IsSet

func (v NullableFloat32) IsSet() bool

func (NullableFloat32) MarshalJSON

func (v NullableFloat32) MarshalJSON() ([]byte, error)

func (*NullableFloat32) Set

func (v *NullableFloat32) Set(val *float32)

func (*NullableFloat32) UnmarshalJSON

func (v *NullableFloat32) UnmarshalJSON(src []byte) error

func (*NullableFloat32) Unset

func (v *NullableFloat32) Unset()

type NullableFloat64

type NullableFloat64 struct {
	// contains filtered or unexported fields
}

func NewNullableFloat64

func NewNullableFloat64(val *float64) *NullableFloat64

func (NullableFloat64) Get

func (v NullableFloat64) Get() *float64

func (NullableFloat64) IsSet

func (v NullableFloat64) IsSet() bool

func (NullableFloat64) MarshalJSON

func (v NullableFloat64) MarshalJSON() ([]byte, error)

func (*NullableFloat64) Set

func (v *NullableFloat64) Set(val *float64)

func (*NullableFloat64) UnmarshalJSON

func (v *NullableFloat64) UnmarshalJSON(src []byte) error

func (*NullableFloat64) Unset

func (v *NullableFloat64) Unset()

type NullableInt

type NullableInt struct {
	// contains filtered or unexported fields
}

func NewNullableInt

func NewNullableInt(val *int) *NullableInt

func (NullableInt) Get

func (v NullableInt) Get() *int

func (NullableInt) IsSet

func (v NullableInt) IsSet() bool

func (NullableInt) MarshalJSON

func (v NullableInt) MarshalJSON() ([]byte, error)

func (*NullableInt) Set

func (v *NullableInt) Set(val *int)

func (*NullableInt) UnmarshalJSON

func (v *NullableInt) UnmarshalJSON(src []byte) error

func (*NullableInt) Unset

func (v *NullableInt) Unset()

type NullableInt32

type NullableInt32 struct {
	// contains filtered or unexported fields
}

func NewNullableInt32

func NewNullableInt32(val *int32) *NullableInt32

func (NullableInt32) Get

func (v NullableInt32) Get() *int32

func (NullableInt32) IsSet

func (v NullableInt32) IsSet() bool

func (NullableInt32) MarshalJSON

func (v NullableInt32) MarshalJSON() ([]byte, error)

func (*NullableInt32) Set

func (v *NullableInt32) Set(val *int32)

func (*NullableInt32) UnmarshalJSON

func (v *NullableInt32) UnmarshalJSON(src []byte) error

func (*NullableInt32) Unset

func (v *NullableInt32) Unset()

type NullableInt64

type NullableInt64 struct {
	// contains filtered or unexported fields
}

func NewNullableInt64

func NewNullableInt64(val *int64) *NullableInt64

func (NullableInt64) Get

func (v NullableInt64) Get() *int64

func (NullableInt64) IsSet

func (v NullableInt64) IsSet() bool

func (NullableInt64) MarshalJSON

func (v NullableInt64) MarshalJSON() ([]byte, error)

func (*NullableInt64) Set

func (v *NullableInt64) Set(val *int64)

func (*NullableInt64) UnmarshalJSON

func (v *NullableInt64) UnmarshalJSON(src []byte) error

func (*NullableInt64) Unset

func (v *NullableInt64) Unset()

type NullableListSWGDeviceSettingsInner

type NullableListSWGDeviceSettingsInner struct {
	// contains filtered or unexported fields
}

func (NullableListSWGDeviceSettingsInner) Get

func (NullableListSWGDeviceSettingsInner) IsSet

func (NullableListSWGDeviceSettingsInner) MarshalJSON

func (v NullableListSWGDeviceSettingsInner) MarshalJSON() ([]byte, error)

func (*NullableListSWGDeviceSettingsInner) Set

func (*NullableListSWGDeviceSettingsInner) UnmarshalJSON

func (v *NullableListSWGDeviceSettingsInner) UnmarshalJSON(src []byte) error

func (*NullableListSWGDeviceSettingsInner) Unset

type NullableListSecureWebGatewayDeviceSettingsRequest

type NullableListSecureWebGatewayDeviceSettingsRequest struct {
	// contains filtered or unexported fields
}

func (NullableListSecureWebGatewayDeviceSettingsRequest) Get

func (NullableListSecureWebGatewayDeviceSettingsRequest) IsSet

func (NullableListSecureWebGatewayDeviceSettingsRequest) MarshalJSON

func (*NullableListSecureWebGatewayDeviceSettingsRequest) Set

func (*NullableListSecureWebGatewayDeviceSettingsRequest) UnmarshalJSON

func (*NullableListSecureWebGatewayDeviceSettingsRequest) Unset

type NullableModelError

type NullableModelError struct {
	// contains filtered or unexported fields
}

func NewNullableModelError

func NewNullableModelError(val *ModelError) *NullableModelError

func (NullableModelError) Get

func (v NullableModelError) Get() *ModelError

func (NullableModelError) IsSet

func (v NullableModelError) IsSet() bool

func (NullableModelError) MarshalJSON

func (v NullableModelError) MarshalJSON() ([]byte, error)

func (*NullableModelError) Set

func (v *NullableModelError) Set(val *ModelError)

func (*NullableModelError) UnmarshalJSON

func (v *NullableModelError) UnmarshalJSON(src []byte) error

func (*NullableModelError) Unset

func (v *NullableModelError) Unset()

type NullableRegisteredSWGDeviceSettings

type NullableRegisteredSWGDeviceSettings struct {
	// contains filtered or unexported fields
}

func (NullableRegisteredSWGDeviceSettings) Get

func (NullableRegisteredSWGDeviceSettings) IsSet

func (NullableRegisteredSWGDeviceSettings) MarshalJSON

func (v NullableRegisteredSWGDeviceSettings) MarshalJSON() ([]byte, error)

func (*NullableRegisteredSWGDeviceSettings) Set

func (*NullableRegisteredSWGDeviceSettings) UnmarshalJSON

func (v *NullableRegisteredSWGDeviceSettings) UnmarshalJSON(src []byte) error

func (*NullableRegisteredSWGDeviceSettings) Unset

type NullableRegisteredSWGDeviceSettingsItemsInner

type NullableRegisteredSWGDeviceSettingsItemsInner struct {
	// contains filtered or unexported fields
}

func (NullableRegisteredSWGDeviceSettingsItemsInner) Get

func (NullableRegisteredSWGDeviceSettingsItemsInner) IsSet

func (NullableRegisteredSWGDeviceSettingsItemsInner) MarshalJSON

func (*NullableRegisteredSWGDeviceSettingsItemsInner) Set

func (*NullableRegisteredSWGDeviceSettingsItemsInner) UnmarshalJSON

func (*NullableRegisteredSWGDeviceSettingsItemsInner) Unset

type NullableString

type NullableString struct {
	// contains filtered or unexported fields
}

func NewNullableString

func NewNullableString(val *string) *NullableString

func (NullableString) Get

func (v NullableString) Get() *string

func (NullableString) IsSet

func (v NullableString) IsSet() bool

func (NullableString) MarshalJSON

func (v NullableString) MarshalJSON() ([]byte, error)

func (*NullableString) Set

func (v *NullableString) Set(val *string)

func (*NullableString) UnmarshalJSON

func (v *NullableString) UnmarshalJSON(src []byte) error

func (*NullableString) Unset

func (v *NullableString) Unset()

type NullableTime

type NullableTime struct {
	// contains filtered or unexported fields
}

func NewNullableTime

func NewNullableTime(val *time.Time) *NullableTime

func (NullableTime) Get

func (v NullableTime) Get() *time.Time

func (NullableTime) IsSet

func (v NullableTime) IsSet() bool

func (NullableTime) MarshalJSON

func (v NullableTime) MarshalJSON() ([]byte, error)

func (*NullableTime) Set

func (v *NullableTime) Set(val *time.Time)

func (*NullableTime) UnmarshalJSON

func (v *NullableTime) UnmarshalJSON(src []byte) error

func (*NullableTime) Unset

func (v *NullableTime) Unset()

type NullableValue

type NullableValue struct {
	// contains filtered or unexported fields
}

func NewNullableValue

func NewNullableValue(val *Value) *NullableValue

func (NullableValue) Get

func (v NullableValue) Get() *Value

func (NullableValue) IsSet

func (v NullableValue) IsSet() bool

func (NullableValue) MarshalJSON

func (v NullableValue) MarshalJSON() ([]byte, error)

func (*NullableValue) Set

func (v *NullableValue) Set(val *Value)

func (*NullableValue) UnmarshalJSON

func (v *NullableValue) UnmarshalJSON(src []byte) error

func (*NullableValue) Unset

func (v *NullableValue) Unset()

type RegisteredSWGDeviceSettings

type RegisteredSWGDeviceSettings struct {
	// The total number of devices that requested to update the device setting.
	TotalCount int64 `json:"totalCount"`
	// The number of devices that successfully changed the device setting.
	SuccessCount int64 `json:"successCount"`
	// The number of devices that failed to change the device setting.
	FailCount int64 `json:"failCount"`
	// The list of device setting status properties.
	Items                []RegisteredSWGDeviceSettingsItemsInner `json:"items"`
	Value                Value                                   `json:"value"`
	AdditionalProperties map[string]interface{}
}

RegisteredSWGDeviceSettings The information about the Secure Web Gateway (SWG) setting for the devices in the organization.

func NewRegisteredSWGDeviceSettings

func NewRegisteredSWGDeviceSettings(totalCount int64, successCount int64, failCount int64, items []RegisteredSWGDeviceSettingsItemsInner, value Value) *RegisteredSWGDeviceSettings

NewRegisteredSWGDeviceSettings instantiates a new RegisteredSWGDeviceSettings object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewRegisteredSWGDeviceSettingsWithDefaults

func NewRegisteredSWGDeviceSettingsWithDefaults() *RegisteredSWGDeviceSettings

NewRegisteredSWGDeviceSettingsWithDefaults instantiates a new RegisteredSWGDeviceSettings object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*RegisteredSWGDeviceSettings) GetFailCount

func (o *RegisteredSWGDeviceSettings) GetFailCount() int64

GetFailCount returns the FailCount field value

func (*RegisteredSWGDeviceSettings) GetFailCountOk

func (o *RegisteredSWGDeviceSettings) GetFailCountOk() (*int64, bool)

GetFailCountOk returns a tuple with the FailCount field value and a boolean to check if the value has been set.

func (*RegisteredSWGDeviceSettings) GetItems

GetItems returns the Items field value

func (*RegisteredSWGDeviceSettings) GetItemsOk

GetItemsOk returns a tuple with the Items field value and a boolean to check if the value has been set.

func (*RegisteredSWGDeviceSettings) GetSuccessCount

func (o *RegisteredSWGDeviceSettings) GetSuccessCount() int64

GetSuccessCount returns the SuccessCount field value

func (*RegisteredSWGDeviceSettings) GetSuccessCountOk

func (o *RegisteredSWGDeviceSettings) GetSuccessCountOk() (*int64, bool)

GetSuccessCountOk returns a tuple with the SuccessCount field value and a boolean to check if the value has been set.

func (*RegisteredSWGDeviceSettings) GetTotalCount

func (o *RegisteredSWGDeviceSettings) GetTotalCount() int64

GetTotalCount returns the TotalCount field value

func (*RegisteredSWGDeviceSettings) GetTotalCountOk

func (o *RegisteredSWGDeviceSettings) GetTotalCountOk() (*int64, bool)

GetTotalCountOk returns a tuple with the TotalCount field value and a boolean to check if the value has been set.

func (*RegisteredSWGDeviceSettings) GetValue

func (o *RegisteredSWGDeviceSettings) GetValue() Value

GetValue returns the Value field value

func (*RegisteredSWGDeviceSettings) GetValueOk

func (o *RegisteredSWGDeviceSettings) GetValueOk() (*Value, bool)

GetValueOk returns a tuple with the Value field value and a boolean to check if the value has been set.

func (RegisteredSWGDeviceSettings) MarshalJSON

func (o RegisteredSWGDeviceSettings) MarshalJSON() ([]byte, error)

func (*RegisteredSWGDeviceSettings) SetFailCount

func (o *RegisteredSWGDeviceSettings) SetFailCount(v int64)

SetFailCount sets field value

func (*RegisteredSWGDeviceSettings) SetItems

SetItems sets field value

func (*RegisteredSWGDeviceSettings) SetSuccessCount

func (o *RegisteredSWGDeviceSettings) SetSuccessCount(v int64)

SetSuccessCount sets field value

func (*RegisteredSWGDeviceSettings) SetTotalCount

func (o *RegisteredSWGDeviceSettings) SetTotalCount(v int64)

SetTotalCount sets field value

func (*RegisteredSWGDeviceSettings) SetValue

func (o *RegisteredSWGDeviceSettings) SetValue(v Value)

SetValue sets field value

func (RegisteredSWGDeviceSettings) ToMap

func (o RegisteredSWGDeviceSettings) ToMap() (map[string]interface{}, error)

func (*RegisteredSWGDeviceSettings) UnmarshalJSON

func (o *RegisteredSWGDeviceSettings) UnmarshalJSON(data []byte) (err error)

type RegisteredSWGDeviceSettingsItemsInner

type RegisteredSWGDeviceSettingsItemsInner struct {
	// The origin ID of the device.
	OriginId int64 `json:"originId"`
	// The status code of the response.
	Code int64 `json:"code"`
	// The description of the response.
	Message              string `json:"message"`
	AdditionalProperties map[string]interface{}
}

RegisteredSWGDeviceSettingsItemsInner The status and description for the device setting.

func NewRegisteredSWGDeviceSettingsItemsInner

func NewRegisteredSWGDeviceSettingsItemsInner(originId int64, code int64, message string) *RegisteredSWGDeviceSettingsItemsInner

NewRegisteredSWGDeviceSettingsItemsInner instantiates a new RegisteredSWGDeviceSettingsItemsInner object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewRegisteredSWGDeviceSettingsItemsInnerWithDefaults

func NewRegisteredSWGDeviceSettingsItemsInnerWithDefaults() *RegisteredSWGDeviceSettingsItemsInner

NewRegisteredSWGDeviceSettingsItemsInnerWithDefaults instantiates a new RegisteredSWGDeviceSettingsItemsInner object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*RegisteredSWGDeviceSettingsItemsInner) GetCode

GetCode returns the Code field value

func (*RegisteredSWGDeviceSettingsItemsInner) GetCodeOk

GetCodeOk returns a tuple with the Code field value and a boolean to check if the value has been set.

func (*RegisteredSWGDeviceSettingsItemsInner) GetMessage

GetMessage returns the Message field value

func (*RegisteredSWGDeviceSettingsItemsInner) GetMessageOk

func (o *RegisteredSWGDeviceSettingsItemsInner) GetMessageOk() (*string, bool)

GetMessageOk returns a tuple with the Message field value and a boolean to check if the value has been set.

func (*RegisteredSWGDeviceSettingsItemsInner) GetOriginId

GetOriginId returns the OriginId field value

func (*RegisteredSWGDeviceSettingsItemsInner) GetOriginIdOk

func (o *RegisteredSWGDeviceSettingsItemsInner) GetOriginIdOk() (*int64, bool)

GetOriginIdOk returns a tuple with the OriginId field value and a boolean to check if the value has been set.

func (RegisteredSWGDeviceSettingsItemsInner) MarshalJSON

func (o RegisteredSWGDeviceSettingsItemsInner) MarshalJSON() ([]byte, error)

func (*RegisteredSWGDeviceSettingsItemsInner) SetCode

SetCode sets field value

func (*RegisteredSWGDeviceSettingsItemsInner) SetMessage

SetMessage sets field value

func (*RegisteredSWGDeviceSettingsItemsInner) SetOriginId

func (o *RegisteredSWGDeviceSettingsItemsInner) SetOriginId(v int64)

SetOriginId sets field value

func (RegisteredSWGDeviceSettingsItemsInner) ToMap

func (o RegisteredSWGDeviceSettingsItemsInner) ToMap() (map[string]interface{}, error)

func (*RegisteredSWGDeviceSettingsItemsInner) UnmarshalJSON

func (o *RegisteredSWGDeviceSettingsItemsInner) UnmarshalJSON(data []byte) (err error)

type SWGDeviceSettingsAPIService

type SWGDeviceSettingsAPIService service

SWGDeviceSettingsAPIService SWGDeviceSettingsAPI service

func (*SWGDeviceSettingsAPIService) CreateSecureWebGatewayDeviceSettings

CreateSecureWebGatewayDeviceSettings Set SWG Override Device Settings

Add a list of origin ID and the Secure Web Gateway (SWG) setting for devices in the organization. The SWG device setting overrides the organization-level SWG setting.

**Note:** Before you can add an SWG override setting to a device, you must register the device as a roaming computer with Secure Access. Secure Access applies the SWG override setting to a device using the device's origin ID. You can list the roaming computers in your organization by sending a request to the Secure Access Roaming Computers API.

@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
@return ApiCreateSecureWebGatewayDeviceSettingsRequest

func (*SWGDeviceSettingsAPIService) CreateSecureWebGatewayDeviceSettingsExecute

Execute executes the request

@return RegisteredSWGDeviceSettings

func (*SWGDeviceSettingsAPIService) DeleteSecureWebGatewayDeviceSettings

DeleteSecureWebGatewayDeviceSettings Delete SWG Override Device Settings

Remove the Secure Web Gateway (SWG) override setting for the devices in the organization. Once you remove the override setting on a device, Secure Access applies your organization's SWG setting to the device.

@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
@return ApiDeleteSecureWebGatewayDeviceSettingsRequest

func (*SWGDeviceSettingsAPIService) DeleteSecureWebGatewayDeviceSettingsExecute

Execute executes the request

@return DeleteSecureWebGatewayDeviceSettings200Response

func (*SWGDeviceSettingsAPIService) ListSecureWebGatewayDeviceSettings

ListSecureWebGatewayDeviceSettings List SWG Override Device Settings

List the Secure Web Gateway (SWG) override setting for devices in the organization.

@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
@return ApiListSecureWebGatewayDeviceSettingsRequest

func (*SWGDeviceSettingsAPIService) ListSecureWebGatewayDeviceSettingsExecute

Execute executes the request

@return []ListSWGDeviceSettingsInner

type ServerConfiguration

type ServerConfiguration struct {
	URL         string
	Description string
	Variables   map[string]ServerVariable
}

ServerConfiguration stores the information about a server

type ServerConfigurations

type ServerConfigurations []ServerConfiguration

ServerConfigurations stores multiple ServerConfiguration items

func (ServerConfigurations) URL

func (sc ServerConfigurations) URL(index int, variables map[string]string) (string, error)

URL formats template on a index using given variables

type ServerVariable

type ServerVariable struct {
	Description  string
	DefaultValue string
	EnumValues   []string
}

ServerVariable stores the information about a server variable

type Value

type Value string

Value Specifies whether to enable the Secure Web Gateway (SWG) device settings. Valid values are: `0` or `1` where `1` indicates enable.

func NewValueFromValue

func NewValueFromValue(v string) (*Value, error)

NewValueFromValue returns a pointer to a valid Value for the value passed as argument, or an error if the value passed is not allowed by the enum

func (Value) IsValid

func (v Value) IsValid() bool

IsValid return true if the value is valid for the enum, false otherwise

func (Value) Ptr

func (v Value) Ptr() *Value

Ptr returns reference to value value

func (*Value) UnmarshalJSON

func (v *Value) UnmarshalJSON(src []byte) error

Jump to